/** ===========================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in
 *   the license agreement under which this software has been supplied.
 *   ==========================================================================
 */

/* =============================================================================
 *   @file  Dmax_example.h
 *
 *   @desc  Header file for DMAX CSL Example.
 * =============================================================================
 */

/* ============================================================================
 *  Revision History
 *  ===============
 *  21-Mar-2005 asr File Created.
 *
 * ============================================================================
 */

#ifndef _DMAX_EXAMPLE_H_
#define _DMAX_EXAMPLE_H_

#ifdef __cplusplus
extern "C"
{
#endif

#include <csl_dmax.h>
#include <soc.h>
#include <csl_intc.h>
#include <stdio.h>
#include <string.h>

#define FILL_CONST    0         /* Used for memory fill functions */
#define FILL_INC      1
#define FILL_DEC      2

#define PASS          0         /* Used as test return flags */
#define ERROR_TEST    1
#define ERROR_FILL    2

/* setting the ISTP value to base of the Vector Table */
#define ISTP_VECTOR_VALUE           0x10000000
/* Number of bytes the Data to be transferred */
#define DMAX_DATA_TRANSFER_COUNT    0x10
/* Transfer Count0 */
#define COUNT0               DMAX_DATA_TRANSFER_COUNT
/* Transfer Count1 */
#define COUNT1               0x0
/* Transfer Count2 */
#define COUNT2               0x0
/* Source Index0 */
#define SRC_INDEX0           0x1
/* Destination Index0 */
#define DST_INDEX0           0x1
/* Source Index1 */
#define SRC_INDEX1           0x0
/* Destination Index1 */
#define DST_INDEX1           0x0
/* Source Index2 */
#define SRC_INDEX2           0x0
/* Destination Index2 */
#define DST_INDEX2           0x0
/* Source Data buffer initialized with this value */
#define SRC_DATA_DEFAULT     0xABCD0034
/* Destination Data buffer initialized with this value */
#define DST_DATA_DEFAULT     0x6789EFEF
/* if there is no Source address, initialize with zero */
#define SRC_ADDR1            0x0
/* if there is no destination address, initialize with zero */
#define DST_ADDR1            0x0
/* Transfer complete sucess */
#define TC_PASS              0x0
/* Error in Transfer complete */
#define TC_FAIL              0x1

/**
 * ============================================================================
 *  @func   dmax_3d_data_transfer
 *
 *  @arg 
 *      NONE
 *
 *  @desc
 *     This routine will setup the values for the 3D data transfer. And verify
 *      once the data is transfered.
 *
 *  @return
 *      CSL_Status
 * ============================================================================
*/
extern CSL_Status dmax_3d_data_transfer( 
                void
);

/**
*******************************************************************************
*   @func   fillMem( Uint32 start_location, Uint32 length,
*                       Uint32 fill_value, Uint8 fill_type )
*
*   @desc   Fills a memory location with a pattern as requested.
*           Beginning at 'start_location', 'length' words (32-bit) are filled,
*           starting with 'fill_value'.  After the initial value, the
*           other memory locations are filled with either a constant
*           value, incrementing values, or decrementing values.
*
*   @arg    Uint32 start_location : Memory location to start filling.
*           Uint32 length : Number of bytes to fill.
*           Uint32 fill_value : 32-bit value to start filling with.
*           Uint8 fill_type : Type of fill:
*                           FILL_CONST, FILL_INC, FILL_DEC
*
*   @return Uint32 flag : PASS for a success
*               ERROR_TEST for a failure
*******************************************************************************
*/
extern Uint32 fillMem (
        Uint32  start_location,
        Uint32  length,
        Uint32  fill_value,
        Uint32  fill_type
);

/**
*******************************************************************************
* @func setup_interrupts
*
* @desc Setting up the Interrupts
*
* @arg  
*   NONE
*
* @return
*   CSL_Status
******************************************************************************/
extern CSL_Status setup_interrupts (
);

/**
*******************************************************************************
* @func intr08
*
* @arg  
*   NONE
*
* @desc Interrupt Service Routine, this will get triggered if the
*       data transfer is success.
*
*
* @return
*   NONE
*******************************************************************************
*/
extern void intr08 (
);

/**
*******************************************************************************
* @func intr07
*
* @arg  
*   NONE
*
* @desc Interrupt Service Routine, this will get triggered if the
*       data transfer fails
*
*
* @return
*   NONE
*******************************************************************************
*/
extern void intr07 (
);

/**
*******************************************************************************
* @func dmax_error_exit
*
* @arg  
*   NONE
* @desc This function closes the DMAX module on error occurence
*
*
* @return
*   NONE
*******************************************************************************
*/
extern void dmax_error_exit (
        void
);

#ifdef __cplusplus
}
#endif

#endif /* _DMAX_EXAMPLE_H_ */
