/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/* =============================================================================
 *   @file  Icache_example.h
 *
 *   @desc  Example header file to ICACHE.
 * =============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  12-may-2005 Ramitha M  File created.
 *
 * =============================================================================
 */

#ifndef _ICACHE_EXAMPLE_H_
#define _ICACHE_EXAMPLE_H_

#ifdef __cplusplus
extern "C"
{
#endif

#include <csl_icache.h>
#include <csl_icacheAux.h>


/* 
 * For every error the error count variable is increased. So count will be 
 * zero when there is no error, So test passed.
 */
#define ICACHE_TEST_PASSED                          0x0

/* computeSum,computeDiff,computeSignDiff are located in memory 
 * such that they fall in different cache lines  
 */
#pragma CODE_SECTION(computeSum, ".test_cache:csl_section:icache");
#pragma CODE_SECTION(computeDiff, ".test_cache:csl_section:icache");


/*
 * =============================================================================
 *   @func   icache_csl_example_test
 *
 *   @arg
 *      NONE
 *
 *   @desc
 *     This function tests the combination of hardware 
 *     control and query commands. 
 *   
 *   @return
 *      NONE   
 *
 * =============================================================================
 */
extern void icache_csl_example_test (
    void
);

/*
 * =============================================================================
 *  @func   computeSum
 *
 *  @arg
 *      NONE
 *
 *  @desc
 *     This is routine computes the sum of the two numbers inputted
 *  
 *  @return
 *      NONE
 * =============================================================================
 */
extern Uint32 computeSum (
    Uint32  num2,
    Uint32  num1
);

/*
 * =============================================================================
 *  @func   computeDiff
 *
 *  @arg
 *      NONE
 *
 *  @desc
 *     This is routine computes the difference of the two numbers inputted
 *  
 *  @return
 *      NONE
 * =============================================================================
 */
extern int computeDiff (
    Uint32  num2,
    Uint32  num1
);


/*
 * =============================================================================
 *   @func   icache_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the icache module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
extern void icache_error_exit (
    void
);


#ifdef __cplusplus
}
#endif


#endif  /* _ICACHE_EXAMPLE_H_ */
