/*  ===========================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in
 *   the license agreement under which this software has been supplied.
 *   ==========================================================================
 */

/** ===========================================================================
 *   @file  Chip_example.c
 *
 *
 *   @desc  Example of CHIP
 *
 * ============================================================================
 *   @n <b> Test Description </b>
 *   @n The example shows how to use chip module.
 *      1. Reading the Value from the Memory Map Register.
 *      2. Writing the value to the Memory Map Register.
 *      3. Reading the value from the Non-Memory Map Register.
 *      4. Writing the value to the Non-Memory Map Regisger. 
 * ============================================================================
 *      
 *   <b> Test Procedure </b>
 *   @verbatim
 *      1. Configure the CCS setup 
 *      2. Please referer CCS manual for setup configuration and loading 
 *          proper GEL file
 *      3. Open project chip_example.pjt
 *      4. Build the project and load the .out file of the project.
 *      5. The test can be executed from the main().
 *          
 *   @endverbatim
 *       
 *   
 * ============================================================================
 */

/* ============================================================================
 *  Revision History
 *  ===============
 *  09-mar-2005 Ramitha Mathew  File created.
 *
 * ============================================================================
 */

#include <csl_chip.h>
#include <soc.h>
#include <stdio.h>

#define CHIP_TEST_PASS      0x0

/* forward declarations */
void chip_csl_example_Test (
    void
);

Uint32 chipTestFail = CHIP_TEST_PASS;
/*
 * ============================================================================
 *   @func   main
 *
 *   @desc
 *     main of test 
 * ============================================================================
*/
void main (
    void
)
{
    chip_csl_example_Test ();
    
    if (chipTestFail == CHIP_TEST_PASS ) {
        printf ("\nCHIP CSL Example Test PASS\n");
    }
    else {
        printf ("\nCHIP CSL Example Test FAIL\n");        
    }     

}

/*
 * ============================================================================
 *   @func   chip_csl_example_Test
 *   @desc
 *      This example shows how chip csl can be utilized to read and write chip
        registers
 *
 *      chip_csl_example_Test();
 *
 * ============================================================================
*/

void chip_csl_example_Test (
    void
)
{
    Uint32                   readValue;
    Uint32                   prevValue;

    CSL_sysInit();
    /* reading MEMCSR  reg- memory mapped register */
    readValue = CSL_chipReadReg (CSL_CHIP_REG_MEMCSR);

    /* writing to MEMCSR  reg */
    prevValue = CSL_chipWriteReg (CSL_CHIP_REG_MEMCSR, readValue);


    if ( prevValue == readValue ) {
        printf("CHIP: Write to MEMCSR ... Passed\n");
    }
    else {
        printf("CHIP: Write to MEMCSR ... Failed\n");
        chipTestFail++;
    }

    /* reading CSR  reg - non memory mapped register */
    readValue = CSL_chipReadReg (CSL_CHIP_REG_CSR);

    /* writing to CSR  reg */
    prevValue = CSL_chipWriteReg (CSL_CHIP_REG_CSR, readValue);
    
    if ( prevValue == readValue ) {
        printf("CHIP: Write to CSR ... Passed\n");
    }
    else {
        printf("CHIP: Write to CSR ... Failed\n");
        chipTestFail++;
    }


}
