/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/* =============================================================================
 *   @file  Spi_example.h
 *
 *   @desc  Example test header file to SPI.
 * =============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  07-Mar-2005 Ganesh K  File created.
 *
 * =============================================================================
 */

#ifndef _SPI_EXAMPLE_H_
#define _SPI_EXAMPLE_H_

#ifdef __cplusplus
extern "C"
{
#endif

#include <csl_pllc.h>
#include <csl_spi.h>
#include <string.h>
#include <stdio.h>

/* 
 * For every error the error count variable is increased. So count will be 
 * zero when there is no error.
 */
#define SPI_TEST_PASSED             0

/*
 * The data to be transmitted through SPI
 */
#define SPI_TX_DATA					0xF0F0

#define SPI_CHK_RX_MASK				0x80
#define SPI_RX_FLG_SET				0x80

#define SPI_DATA_FMT_CHARLEN_16BIT	0x10

#define SPI_PINCTRL_SPIFUNC_3PIN	0x0E00

#define SPI_PLLC_DIV_RATIO			0x001u

/*
 * =============================================================================
 *  @func   spi_csl_example_test
 *
 *  @desc
 *     This is the test routine which transmit and verify data in loop back mode
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
*/
extern void spi_csl_example_test (
    void
);

/*
 * =============================================================================
 *  @func   spi_error_exit
 *
 *  @desc
 *     This calls the module close function in case of error 
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
 */
extern void spi_error_exit (
    void
);

#ifdef __cplusplus
}
#endif


#endif        /* _SPI_EXAMPLE_H_ */
