/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/* =============================================================================
 *   @file  Emif_example.h
 *
 *   @desc  Example test header file to EMIF.
 * =============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  12-may-2005 Ganesh K  File created.
 *
 * =============================================================================
 */

#ifndef _EMIF_EXAMPLE_H_
#define _EMIF_EXAMPLE_H_

#ifdef __cplusplus
extern                   "C"
{
#endif

#include <csl_emif.h>
#include <soc.h>
#include <stdio.h>

/* 
 * For every error the error count variable is increased. So count will be 
 * zero when there is no error. 
 */
#define EMIF_TEST_PASSED				0

/* Start address of SDRAM according to C672x memory map */
#define EMIF_TEST_SDRAM_START_ADDR		0x80000000

/* 
 * Number of blocks to be tested. This is value can be changed if more
 * memory space is to be tested. The example test (0xF x 0xFF) words of
 * SDRAM memory space.
 */
#define EMIF_TEST_BLOCK_COUNT			0x0F

/* Number of characters present per block */
#define EMIF_TEST_BLOCK_MAX_CHAR		0x0FF

/* SDRAM refresh value */
#define EMIF_TEST_SDRAM_REFRESH         0x5FF

/* SDRAM timer register configuration macros */
#define EMIF_TEST_EM_CLK_CYCLES_1       1
#define EMIF_TEST_EM_CLK_CYCLES_2       2
#define EMIF_TEST_EM_CLK_CYCLES_3       3
#define EMIF_TEST_EM_CLK_CYCLES_4       4
#define EMIF_TEST_EM_CLK_CYCLES_5       5
#define EMIF_TEST_EM_CLK_CYCLES_6       6

/* SDRAM self referesh exit timing register configuration value */
#define EMIF_TEST_ECLKOUT_CYCLES_6      6

/*
 * =============================================================================
 *  @func   emif_csl_example_test
 *
 *  @desc
 *     This is the test routine which write, read and verify data of SDRAM.
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
 */
    extern void              emif_csl_example_test (
        void
    );

/*
 * =============================================================================
 *  @func   emif_error_exit
 *
 *  @desc
 *     This calls the module close function in case of error 
 *
 *  @arg
 *      NONE
 *  
 *  @return
 *      NONE
 * =============================================================================
 */
    extern void              emif_error_exit (
        void
    );


#ifdef __cplusplus
}
#endif


#endif                          /* _EMIF_EXAMPLE_H_ */
