/* =============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *   file   cslr_i2c.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for I2C
 *          Reference: User Guide SPRU877D
 *  ============================================================================
 */
 
#ifndef _CSLR_I2C_H_
#define _CSLR_I2C_H_

#include <cslr.h>
#include <tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 I2COAR;
    volatile Uint32 I2CIER;
    volatile Uint32 I2CSTR;
    volatile Uint32 I2CCLKL;
    volatile Uint32 I2CCLKH;
    volatile Uint32 I2CCNT;
    volatile Uint32 I2CDRR;
    volatile Uint32 I2CSAR;
    volatile Uint32 I2CDXR;
    volatile Uint32 I2CMDR;
    volatile Uint32 I2CISR;
    volatile Uint32 I2CEMDR;
    volatile Uint32 I2CPSC;
    volatile Uint32 I2CPID1;
    volatile Uint32 I2CPID2;
    volatile Uint8 RSVD0[12];
    volatile Uint32 I2CPFUNC;
    volatile Uint32 I2CPDIR;
    volatile Uint32 I2CPDIN;
    volatile Uint32 I2CPDOUT;
    volatile Uint32 I2CPDSET;
    volatile Uint32 I2CPDCLR;
} CSL_I2cRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_I2cRegs             *CSL_I2cRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* I2COAR */



#define CSL_I2C_I2COAR_OADDR_MASK (0x000003FFu)
#define CSL_I2C_I2COAR_OADDR_SHIFT (0x00000000u)
#define CSL_I2C_I2COAR_OADDR_RESETVAL (0x00000000u)

#define CSL_I2C_I2COAR_RESETVAL (0x00000000u)

/* I2CIER */



#define CSL_I2C_I2CIER_AAS_MASK (0x00000040u)
#define CSL_I2C_I2CIER_AAS_SHIFT (0x00000006u)
#define CSL_I2C_I2CIER_AAS_RESETVAL (0x00000000u)
/*----AAS Tokens----*/
#define CSL_I2C_I2CIER_AAS_DISABLE (0x00000000u)
#define CSL_I2C_I2CIER_AAS_ENABLE (0x00000001u)

#define CSL_I2C_I2CIER_SCD_MASK (0x00000020u)
#define CSL_I2C_I2CIER_SCD_SHIFT (0x00000005u)
#define CSL_I2C_I2CIER_SCD_RESETVAL (0x00000000u)
/*----SCD Tokens----*/
#define CSL_I2C_I2CIER_SCD_DISABLE (0x00000000u)
#define CSL_I2C_I2CIER_SCD_ENABLE (0x00000001u)

#define CSL_I2C_I2CIER_ICXRDY_MASK (0x00000010u)
#define CSL_I2C_I2CIER_ICXRDY_SHIFT (0x00000004u)
#define CSL_I2C_I2CIER_ICXRDY_RESETVAL (0x00000000u)
/*----ICXRDY Tokens----*/
#define CSL_I2C_I2CIER_ICXRDY_DISABLE (0x00000000u)
#define CSL_I2C_I2CIER_ICXRDY_ENABLE (0x00000001u)

#define CSL_I2C_I2CIER_ICRRDY_MASK (0x00000008u)
#define CSL_I2C_I2CIER_ICRRDY_SHIFT (0x00000003u)
#define CSL_I2C_I2CIER_ICRRDY_RESETVAL (0x00000000u)
/*----ICRRDY Tokens----*/
#define CSL_I2C_I2CIER_ICRRDY_DISABLE (0x00000000u)
#define CSL_I2C_I2CIER_ICRRDY_ENABLE (0x00000001u)

#define CSL_I2C_I2CIER_ARDY_MASK (0x00000004u)
#define CSL_I2C_I2CIER_ARDY_SHIFT (0x00000002u)
#define CSL_I2C_I2CIER_ARDY_RESETVAL (0x00000000u)
/*----ARDY Tokens----*/
#define CSL_I2C_I2CIER_ARDY_DISABLE (0x00000000u)
#define CSL_I2C_I2CIER_ARDY_ENABLE (0x00000001u)

#define CSL_I2C_I2CIER_NACK_MASK (0x00000002u)
#define CSL_I2C_I2CIER_NACK_SHIFT (0x00000001u)
#define CSL_I2C_I2CIER_NACK_RESETVAL (0x00000000u)
/*----NACK Tokens----*/
#define CSL_I2C_I2CIER_NACK_DISABLE (0x00000000u)
#define CSL_I2C_I2CIER_NACK_ENABLE (0x00000001u)

#define CSL_I2C_I2CIER_AL_MASK (0x00000001u)
#define CSL_I2C_I2CIER_AL_SHIFT (0x00000000u)
#define CSL_I2C_I2CIER_AL_RESETVAL (0x00000000u)
/*----AL Tokens----*/
#define CSL_I2C_I2CIER_AL_DISABLE (0x00000000u)
#define CSL_I2C_I2CIER_AL_ENABLE (0x00000001u)

#define CSL_I2C_I2CIER_RESETVAL (0x00000000u)

/* I2CSTR */



#define CSL_I2C_I2CSTR_SDIR_MASK (0x00004000u)
#define CSL_I2C_I2CSTR_SDIR_SHIFT (0x0000000Eu)
#define CSL_I2C_I2CSTR_SDIR_RESETVAL (0x00000000u)
/*----SDIR Tokens----*/
#define CSL_I2C_I2CSTR_SDIR_MASTER (0x00000000u)
#define CSL_I2C_I2CSTR_SDIR_SLAVE (0x00000001u)
#define CSL_I2C_I2CSTR_SDIR_CLEAR (0x00000001u)

#define CSL_I2C_I2CSTR_NACKSNT_MASK (0x00002000u)
#define CSL_I2C_I2CSTR_NACKSNT_SHIFT (0x0000000Du)
#define CSL_I2C_I2CSTR_NACKSNT_RESETVAL (0x00000000u)
/*----NACKSNT Tokens----*/
#define CSL_I2C_I2CSTR_NACKSNT_NO_ACK (0x00000000u)
#define CSL_I2C_I2CSTR_NACKSNT_NACK (0x00000001u)
#define CSL_I2C_I2CSTR_NACKSNT_CLEAR (0x00000001u)

#define CSL_I2C_I2CSTR_BB_MASK (0x00001000u)
#define CSL_I2C_I2CSTR_BB_SHIFT (0x0000000Cu)
#define CSL_I2C_I2CSTR_BB_RESETVAL (0x00000000u)
/*----BB Tokens----*/
#define CSL_I2C_I2CSTR_BB_FREE (0x00000000u)
#define CSL_I2C_I2CSTR_BB_BUSY (0x00000001u)
#define CSL_I2C_I2CSTR_BB_CLEAR (0x00000001u)

#define CSL_I2C_I2CSTR_RSFULL_MASK (0x00000800u)
#define CSL_I2C_I2CSTR_RSFULL_SHIFT (0x0000000Bu)
#define CSL_I2C_I2CSTR_RSFULL_RESETVAL (0x00000000u)
/*----RSFULL Tokens----*/
#define CSL_I2C_I2CSTR_RSFULL_NO_OVERRUN (0x00000000u)
#define CSL_I2C_I2CSTR_RSFULL_OVERRUN (0x00000001u)

#define CSL_I2C_I2CSTR_XSMT_MASK (0x00000400u)
#define CSL_I2C_I2CSTR_XSMT_SHIFT (0x0000000Au)
#define CSL_I2C_I2CSTR_XSMT_RESETVAL (0x00000001u)
/*----XSMT Tokens----*/
#define CSL_I2C_I2CSTR_XSMT_UNDERFLOW (0x00000000u)
#define CSL_I2C_I2CSTR_XSMT_NO_UNDERFLOW (0x00000001u)

#define CSL_I2C_I2CSTR_AAS_MASK (0x00000200u)
#define CSL_I2C_I2CSTR_AAS_SHIFT (0x00000009u)
#define CSL_I2C_I2CSTR_AAS_RESETVAL (0x00000000u)
/*----AAS Tokens----*/
#define CSL_I2C_I2CSTR_AAS_CLEAR (0x00000000u)
#define CSL_I2C_I2CSTR_AAS_SET (0x00000001u)

#define CSL_I2C_I2CSTR_AD0_MASK (0x00000100u)
#define CSL_I2C_I2CSTR_AD0_SHIFT (0x00000008u)
#define CSL_I2C_I2CSTR_AD0_RESETVAL (0x00000000u)
/*----AD0 Tokens----*/
#define CSL_I2C_I2CSTR_AD0_NO (0x00000000u)
#define CSL_I2C_I2CSTR_AD0_YES (0x00000001u)


#define CSL_I2C_I2CSTR_SCD_MASK (0x00000020u)
#define CSL_I2C_I2CSTR_SCD_SHIFT (0x00000005u)
#define CSL_I2C_I2CSTR_SCD_RESETVAL (0x00000000u)
/*----SCD Tokens----*/
#define CSL_I2C_I2CSTR_SCD_NO (0x00000000u)
#define CSL_I2C_I2CSTR_SCD_YES (0x00000001u)
#define CSL_I2C_I2CSTR_SCD_CLEAR (0x00000001u)

#define CSL_I2C_I2CSTR_ICXRDY_MASK (0x00000010u)
#define CSL_I2C_I2CSTR_ICXRDY_SHIFT (0x00000004u)
#define CSL_I2C_I2CSTR_ICXRDY_RESETVAL (0x00000001u)
/*----ICXRDY Tokens----*/
#define CSL_I2C_I2CSTR_ICXRDY_FALSE (0x00000000u)
#define CSL_I2C_I2CSTR_ICXRDY_TRUE (0x00000001u)
#define CSL_I2C_I2CSTR_ICXRDY_CLEAR (0x00000001u)

#define CSL_I2C_I2CSTR_ICRRDY_MASK (0x00000008u)
#define CSL_I2C_I2CSTR_ICRRDY_SHIFT (0x00000003u)
#define CSL_I2C_I2CSTR_ICRRDY_RESETVAL (0x00000000u)
/*----ICRRDY Tokens----*/
#define CSL_I2C_I2CSTR_ICRRDY_FALSE (0x00000000u)
#define CSL_I2C_I2CSTR_ICRRDY_TRUE (0x00000001u)
#define CSL_I2C_I2CSTR_ICRRDY_CLEAR (0x00000001u)

#define CSL_I2C_I2CSTR_ARDY_MASK (0x00000004u)
#define CSL_I2C_I2CSTR_ARDY_SHIFT (0x00000002u)
#define CSL_I2C_I2CSTR_ARDY_RESETVAL (0x00000000u)
/*----ARDY Tokens----*/
#define CSL_I2C_I2CSTR_ARDY_FALSE (0x00000000u)
#define CSL_I2C_I2CSTR_ARDY_TRUE (0x00000001u)
#define CSL_I2C_I2CSTR_ARDY_CLEAR (0x00000001u)

#define CSL_I2C_I2CSTR_NACK_MASK (0x00000002u)
#define CSL_I2C_I2CSTR_NACK_SHIFT (0x00000001u)
#define CSL_I2C_I2CSTR_NACK_RESETVAL (0x00000000u)
/*----NACK Tokens----*/
#define CSL_I2C_I2CSTR_NACK_FALSE (0x00000000u)
#define CSL_I2C_I2CSTR_NACK_TRUE (0x00000001u)
#define CSL_I2C_I2CSTR_NACK_CLEAR (0x00000001u)

#define CSL_I2C_I2CSTR_AL_MASK (0x00000001u)
#define CSL_I2C_I2CSTR_AL_SHIFT (0x00000000u)
#define CSL_I2C_I2CSTR_AL_RESETVAL (0x00000000u)
/*----AL Tokens----*/
#define CSL_I2C_I2CSTR_AL_FALSE (0x00000000u)

#define CSL_I2C_I2CSTR_RESETVAL (0x00000410u)

/* I2CCLKL */


#define CSL_I2C_I2CCLKL_ICCL_MASK (0x0000FFFFu)
#define CSL_I2C_I2CCLKL_ICCL_SHIFT (0x00000000u)
#define CSL_I2C_I2CCLKL_ICCL_RESETVAL (0x00000000u)

#define CSL_I2C_I2CCLKL_RESETVAL (0x00000000u)

/* I2CCLKH */


#define CSL_I2C_I2CCLKH_ICCH_MASK (0x0000FFFFu)
#define CSL_I2C_I2CCLKH_ICCH_SHIFT (0x00000000u)
#define CSL_I2C_I2CCLKH_ICCH_RESETVAL (0x00000000u)

#define CSL_I2C_I2CCLKH_RESETVAL (0x00000000u)

/* I2CCNT */


#define CSL_I2C_I2CCNT_ICDC_MASK (0x0000FFFFu)
#define CSL_I2C_I2CCNT_ICDC_SHIFT (0x00000000u)
#define CSL_I2C_I2CCNT_ICDC_RESETVAL (0x00000000u)

#define CSL_I2C_I2CCNT_RESETVAL (0x00000000u)

/* I2CDRR */


#define CSL_I2C_I2CDRR_D_MASK (0x000000FFu)
#define CSL_I2C_I2CDRR_D_SHIFT (0x00000000u)
#define CSL_I2C_I2CDRR_D_RESETVAL (0x00000000u)

#define CSL_I2C_I2CDRR_RESETVAL (0x00000000u)

/* I2CSAR */


#define CSL_I2C_I2CSAR_SADDR_MASK (0x000003FFu)
#define CSL_I2C_I2CSAR_SADDR_SHIFT (0x00000000u)
#define CSL_I2C_I2CSAR_SADDR_RESETVAL (0x000003FFu)

#define CSL_I2C_I2CSAR_RESETVAL (0x000003FFu)

/* I2CDXR */



#define CSL_I2C_I2CDXR_D_MASK (0x000000FFu)
#define CSL_I2C_I2CDXR_D_SHIFT (0x00000000u)
#define CSL_I2C_I2CDXR_D_RESETVAL (0x00000000u)

#define CSL_I2C_I2CDXR_RESETVAL (0x00000000u)

/* I2CMDR */


#define CSL_I2C_I2CMDR_NACKMOD_MASK (0x00008000u)
#define CSL_I2C_I2CMDR_NACKMOD_SHIFT (0x0000000Fu)
#define CSL_I2C_I2CMDR_NACKMOD_RESETVAL (0x00000000u)
/*----NACKMOD Tokens----*/
#define CSL_I2C_I2CMDR_NACKMOD_SLAVE_RX (0x00000000u)
#define CSL_I2C_I2CMDR_NACKMOD_MASTER_SLAVE_RX (0x00000001u)

#define CSL_I2C_I2CMDR_FREE_MASK (0x00004000u)
#define CSL_I2C_I2CMDR_FREE_SHIFT (0x0000000Eu)
#define CSL_I2C_I2CMDR_FREE_RESETVAL (0x00000000u)
/*----FREE Tokens----*/
#define CSL_I2C_I2CMDR_FREE_FALSE (0x00000000u)
#define CSL_I2C_I2CMDR_FREE_TRUE (0x00000001u)

#define CSL_I2C_I2CMDR_STT_MASK (0x00002000u)
#define CSL_I2C_I2CMDR_STT_SHIFT (0x0000000Du)
#define CSL_I2C_I2CMDR_STT_RESETVAL (0x00000000u)
/*----STT Tokens----*/
#define CSL_I2C_I2CMDR_STT_CLEAR (0x00000000u)
#define CSL_I2C_I2CMDR_STT_SET (0x00000001u)


#define CSL_I2C_I2CMDR_STP_MASK (0x00000800u)
#define CSL_I2C_I2CMDR_STP_SHIFT (0x0000000Bu)
#define CSL_I2C_I2CMDR_STP_RESETVAL (0x00000000u)
/*----STP Tokens----*/
#define CSL_I2C_I2CMDR_STP_CLEAR (0x00000000u)
#define CSL_I2C_I2CMDR_STP_SET (0x00000001u)

#define CSL_I2C_I2CMDR_MST_MASK (0x00000400u)
#define CSL_I2C_I2CMDR_MST_SHIFT (0x0000000Au)
#define CSL_I2C_I2CMDR_MST_RESETVAL (0x00000000u)
/*----MST Tokens----*/
#define CSL_I2C_I2CMDR_MST_SLAVE (0x00000000u)
#define CSL_I2C_I2CMDR_MST_MASTER (0x00000001u)

#define CSL_I2C_I2CMDR_TRX_MASK (0x00000200u)
#define CSL_I2C_I2CMDR_TRX_SHIFT (0x00000009u)
#define CSL_I2C_I2CMDR_TRX_RESETVAL (0x00000000u)
/*----TRX Tokens----*/
#define CSL_I2C_I2CMDR_TRX_RX_MODE (0x00000000u)
#define CSL_I2C_I2CMDR_TRX_TX_MODE (0x00000001u)

#define CSL_I2C_I2CMDR_XA_MASK (0x00000100u)
#define CSL_I2C_I2CMDR_XA_SHIFT (0x00000008u)
#define CSL_I2C_I2CMDR_XA_RESETVAL (0x00000000u)
/*----XA Tokens----*/
#define CSL_I2C_I2CMDR_XA_7BIT (0x00000000u)
#define CSL_I2C_I2CMDR_XA_ (0x0000000Au)

#define CSL_I2C_I2CMDR_RM_MASK (0x00000080u)
#define CSL_I2C_I2CMDR_RM_SHIFT (0x00000007u)
#define CSL_I2C_I2CMDR_RM_RESETVAL (0x00000000u)
/*----RM Tokens----*/
#define CSL_I2C_I2CMDR_RM_DISABLE (0x00000000u)
#define CSL_I2C_I2CMDR_RM_ENABLE (0x00000001u)

#define CSL_I2C_I2CMDR_DLB_MASK (0x00000040u)
#define CSL_I2C_I2CMDR_DLB_SHIFT (0x00000006u)
#define CSL_I2C_I2CMDR_DLB_RESETVAL (0x00000000u)
/*----DLB Tokens----*/
#define CSL_I2C_I2CMDR_DLB_DISABLE (0x00000000u)
#define CSL_I2C_I2CMDR_DLB_ENABLE (0x00000001u)

#define CSL_I2C_I2CMDR_IRS_MASK (0x00000020u)
#define CSL_I2C_I2CMDR_IRS_SHIFT (0x00000005u)
#define CSL_I2C_I2CMDR_IRS_RESETVAL (0x00000000u)
/*----IRS Tokens----*/
#define CSL_I2C_I2CMDR_IRS_RESET (0x00000000u)
#define CSL_I2C_I2CMDR_IRS_DISABLE (0x00000000u)
#define CSL_I2C_I2CMDR_IRS_ENABLE (0x00000001u)

#define CSL_I2C_I2CMDR_STB_MASK (0x00000010u)
#define CSL_I2C_I2CMDR_STB_SHIFT (0x00000004u)
#define CSL_I2C_I2CMDR_STB_RESETVAL (0x00000000u)
/*----STB Tokens----*/
#define CSL_I2C_I2CMDR_STB_DISABLE (0x00000000u)
#define CSL_I2C_I2CMDR_STB_ENABLE (0x00000001u)

#define CSL_I2C_I2CMDR_FDF_MASK (0x00000008u)
#define CSL_I2C_I2CMDR_FDF_SHIFT (0x00000003u)
#define CSL_I2C_I2CMDR_FDF_RESETVAL (0x00000000u)
/*----FDF Tokens----*/
#define CSL_I2C_I2CMDR_FDF_DISABLE (0x00000000u)
#define CSL_I2C_I2CMDR_FDF_ENABLE (0x00000001u)

#define CSL_I2C_I2CMDR_BC_MASK (0x00000007u)
#define CSL_I2C_I2CMDR_BC_SHIFT (0x00000000u)
#define CSL_I2C_I2CMDR_BC_RESETVAL (0x00000000u)
#define CSL_I2C_I2CMDR_BC_8BIT (0x00000000u)
#define CSL_I2C_I2CMDR_BC_2BIT (0x00000002u)
#define CSL_I2C_I2CMDR_BC_3BIT (0x00000003u)
#define CSL_I2C_I2CMDR_BC_4BIT (0x00000004u)
#define CSL_I2C_I2CMDR_BC_5BIT (0x00000005u)
#define CSL_I2C_I2CMDR_BC_6BIT (0x00000006u)
#define CSL_I2C_I2CMDR_BC_7BIT (0x00000007u)

#define CSL_I2C_I2CMDR_RESETVAL (0x00000000u)

/* I2CISR */


#define CSL_I2C_I2CISR_INTCODE_MASK (0x00000007u)
#define CSL_I2C_I2CISR_INTCODE_SHIFT (0x00000000u)
#define CSL_I2C_I2CISR_INTCODE_RESETVAL (0x00000000u)
/*----INTCODE Tokens----*/
#define CSL_I2C_I2CISR_INTCODE_NONE (0x00000000u)
#define CSL_I2C_I2CISR_INTCODE_AL (0x00000001u)
#define CSL_I2C_I2CISR_INTCODE_NACK (0x00000002u)
#define CSL_I2C_I2CISR_INTCODE_RAR (0x00000003u)
#define CSL_I2C_I2CISR_INTCODE_RDR (0x00000004u)
#define CSL_I2C_I2CISR_INTCODE_TDR (0x00000005u)
#define CSL_I2C_I2CISR_INTCODE_SCD (0x00000006u)
#define CSL_I2C_I2CISR_INTCODE_AAS (0x00000007u)

#define CSL_I2C_I2CISR_RESETVAL (0x00000000u)

/* I2CEMDR */



#define CSL_I2C_I2CEMDR_XRDYM_MASK (0x00000001u)
#define CSL_I2C_I2CEMDR_XRDYM_SHIFT (0x00000000u)
#define CSL_I2C_I2CEMDR_XRDYM_RESETVAL (0x00000001u)

#define CSL_I2C_I2CEMDR_RESETVAL (0x00000001u)

/* I2CPSC */



#define CSL_I2C_I2CPSC_IPSC_MASK (0x000000FFu)
#define CSL_I2C_I2CPSC_IPSC_SHIFT (0x00000000u)
#define CSL_I2C_I2CPSC_IPSC_RESETVAL (0x00000000u)

#define CSL_I2C_I2CPSC_RESETVAL (0x00000000u)

/* I2CPID1 */


#define CSL_I2C_I2CPID1_CLASS_MASK (0x0000FF00u)
#define CSL_I2C_I2CPID1_CLASS_SHIFT (0x00000008u)
#define CSL_I2C_I2CPID1_CLASS_RESETVAL (0x00000001u)

#define CSL_I2C_I2CPID1_REVISION_MASK (0x000000FFu)
#define CSL_I2C_I2CPID1_REVISION_SHIFT (0x00000000u)
#define CSL_I2C_I2CPID1_REVISION_RESETVAL (0x00000025u)

#define CSL_I2C_I2CPID1_RESETVAL (0x00000125u)

/* I2CPID2 */



#define CSL_I2C_I2CPID2_TYPE_MASK (0x000000FFu)
#define CSL_I2C_I2CPID2_TYPE_SHIFT (0x00000000u)
#define CSL_I2C_I2CPID2_TYPE_RESETVAL (0x00000005u)

#define CSL_I2C_I2CPID2_RESETVAL (0x00000005u)

/* I2CPFUNC */


#define CSL_I2C_I2CPFUNC_GPMODE_MASK (0x00000001u)
#define CSL_I2C_I2CPFUNC_GPMODE_SHIFT (0x00000000u)
#define CSL_I2C_I2CPFUNC_GPMODE_RESETVAL (0x00000000u)
/*----GPMODE Tokens----*/
#define CSL_I2C_I2CPFUNC_GPMODE_DISABLE (0x00000000u)
#define CSL_I2C_I2CPFUNC_GPMODE_ENABLE (0x00000001u)

#define CSL_I2C_I2CPFUNC_RESETVAL (0x00000000u)

/* I2CPDIR */


#define CSL_I2C_I2CPDIR_SDADIR_MASK (0x00000002u)
#define CSL_I2C_I2CPDIR_SDADIR_SHIFT (0x00000001u)
#define CSL_I2C_I2CPDIR_SDADIR_RESETVAL (0x00000000u)
/*----SDADIR Tokens----*/
#define CSL_I2C_I2CPDIR_SDADIR_IN (0x00000000u)
#define CSL_I2C_I2CPDIR_SDADIR_OUT (0x00000001u)

#define CSL_I2C_I2CPDIR_SCLDIR_MASK (0x00000001u)
#define CSL_I2C_I2CPDIR_SCLDIR_SHIFT (0x00000000u)
#define CSL_I2C_I2CPDIR_SCLDIR_RESETVAL (0x00000000u)
/*----SCLDIR Tokens----*/
#define CSL_I2C_I2CPDIR_SCLDIR_IN (0x00000000u)
#define CSL_I2C_I2CPDIR_SCLDIR_OUT (0x00000001u)

#define CSL_I2C_I2CPDIR_RESETVAL (0x00000000u)

/* I2CPDIN */


#define CSL_I2C_I2CPDIN_SDAIN_MASK (0x00000002u)
#define CSL_I2C_I2CPDIN_SDAIN_SHIFT (0x00000001u)
#define CSL_I2C_I2CPDIN_SDAIN_RESETVAL (0x00000000u)
/*----SDAIN Tokens----*/
#define CSL_I2C_I2CPDIN_SDAIN_LOW (0x00000000u)
#define CSL_I2C_I2CPDIN_SDAIN_HIGH (0x00000001u)

#define CSL_I2C_I2CPDIN_SCLIN_MASK (0x00000001u)
#define CSL_I2C_I2CPDIN_SCLIN_SHIFT (0x00000000u)
#define CSL_I2C_I2CPDIN_SCLIN_RESETVAL (0x00000000u)
/*----SCLIN Tokens----*/
#define CSL_I2C_I2CPDIN_SCLIN_LOW (0x00000000u)
#define CSL_I2C_I2CPDIN_SCLIN_HIGH (0x00000001u)

#define CSL_I2C_I2CPDIN_RESETVAL (0x00000000u)

/* I2CPDOUT */


#define CSL_I2C_I2CPDOUT_SDAOUT_MASK (0x00000002u)
#define CSL_I2C_I2CPDOUT_SDAOUT_SHIFT (0x00000001u)
#define CSL_I2C_I2CPDOUT_SDAOUT_RESETVAL (0x00000000u)
/*----SDAOUT Tokens----*/
#define CSL_I2C_I2CPDOUT_SDAOUT_LOW (0x00000000u)
#define CSL_I2C_I2CPDOUT_SDAOUT_HIGH (0x00000001u)

#define CSL_I2C_I2CPDOUT_SCLOUT_MASK (0x00000001u)
#define CSL_I2C_I2CPDOUT_SCLOUT_SHIFT (0x00000000u)
#define CSL_I2C_I2CPDOUT_SCLOUT_RESETVAL (0x00000000u)
/*----SCLOUT Tokens----*/
#define CSL_I2C_I2CPDOUT_SCLOUT_LOW (0x00000000u)
#define CSL_I2C_I2CPDOUT_SCLOUT_HIGH (0x00000001u)

#define CSL_I2C_I2CPDOUT_RESETVAL (0x00000000u)

/* I2CPDSET */


#define CSL_I2C_I2CPDSET_SDAOUT_MASK (0x00000002u)
#define CSL_I2C_I2CPDSET_SDAOUT_SHIFT (0x00000001u)
#define CSL_I2C_I2CPDSET_SDAOUT_RESETVAL (0x00000000u)
/*----SDAOUT Tokens----*/
#define CSL_I2C_I2CPDSET_SDAOUT_NONE (0x00000000u)
#define CSL_I2C_I2CPDSET_SDAOUT_SET (0x00000001u)

#define CSL_I2C_I2CPDSET_SCLOUT_MASK (0x00000001u)
#define CSL_I2C_I2CPDSET_SCLOUT_SHIFT (0x00000000u)
#define CSL_I2C_I2CPDSET_SCLOUT_RESETVAL (0x00000000u)
/*----SCLOUT Tokens----*/
#define CSL_I2C_I2CPDSET_SCLOUT_NONE (0x00000000u)
#define CSL_I2C_I2CPDSET_SCLOUT_SET (0x00000001u)

#define CSL_I2C_I2CPDSET_RESETVAL (0x00000000u)

/* I2CPDCLR */


#define CSL_I2C_I2CPDCLR_SDAOUT_MASK (0x00000002u)
#define CSL_I2C_I2CPDCLR_SDAOUT_SHIFT (0x00000001u)
#define CSL_I2C_I2CPDCLR_SDAOUT_RESETVAL (0x00000000u)
/*----SDAOUT Tokens----*/
#define CSL_I2C_I2CPDCLR_SDAOUT_NONE (0x00000000u)
#define CSL_I2C_I2CPDCLR_SDAOUT_RESET (0x00000001u)

#define CSL_I2C_I2CPDCLR_SCLOUT_MASK (0x00000001u)
#define CSL_I2C_I2CPDCLR_SCLOUT_SHIFT (0x00000000u)
#define CSL_I2C_I2CPDCLR_SCLOUT_RESETVAL (0x00000000u)
/*----SCLOUT Tokens----*/
#define CSL_I2C_I2CPDCLR_SCLOUT_NONE (0x00000000u)
#define CSL_I2C_I2CPDCLR_SCLOUT_RESET (0x00000001u)

#define CSL_I2C_I2CPDCLR_RESETVAL (0x00000000u)

#endif
