/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/* =============================================================================
 *   @file  Intc_example.h
 *
 *   @desc  Example header file for INTC.
 * =============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  09-mar-2005 Ramitha M  File created.
 *
 * =============================================================================
 */

#ifndef _INTC_EXAMPLE_H_
#define _INTC_EXAMPLE_H_

#ifdef __cplusplus
extern "C"
{
#endif

#include <csl_pllc.h>
#include <soc.h>
#include <csl_rti.h>
#include <csl_intc.h>
#include <stdio.h>
#include <string.h>

/* 
 * For every error the error count variable is increased. So count will be 
 * zero when there is no error, So test passed.
 */
#define INTC_TEST_PASSED         0x0

/* RAM address to which Interrupt vector table is to be loacated */
#define DEST_ADDR   			 0x10000000

/* Load value to watchdog timer */
#define PRELOAD_VALUE            0x1FF

/* Macros for functional clock value */
#define RTI_INPUT_CLOCK          32000000
#define DIVIDER_FOR_TEST         4
#define EFFECTIVE_CLOCK_FOR_TEST (RTI_INPUT_CLOCK/DIVIDER_FOR_TEST)
#define UP_COMP_INTERVAL         1
#define COMP_INTERVAL            3             

/* Test intervals used for tests  */
#define UC_COMP_VALUE      		((UP_COMP_INTERVAL * EFFECTIVE_CLOCK_FOR_TEST)\
								/1000)
#define COMPARE0_VALUE      	(COMP_INTERVAL)
#define COMPARE1_VALUE      	(COMP_INTERVAL)
#define COMPARE2_VALUE      	(COMP_INTERVAL)
#define COMPARE3_VALUE      	(COMP_INTERVAL)
#define UPDATECOMPARE_VALUE     (UP_COMP_INTERVAL)


/*
 * =============================================================================
 *   @func   intc_csl_example_Test
 *
 *	 @arg
 *		NONE
 *
 *   @desc
 *     Example test routine which calls test function and intialize ISR 
 *
 *	@return
 *		NONE
 *
 * =============================================================================
 */
extern void intc_csl_example_Test(
	void
);

/*
 * =============================================================================
 *   @func   example_test
 *
 *   @arg
 *		testNum     - The number of the test to be tested
 *
 *   @desc
 *     Test routine which performs different test depending on the test number
 *
 *   @return
 *      NONE
 *
 * =============================================================================
 */
extern void example_test (
	Uint16 	testNum
);

/*
 * =============================================================================
 *   @func   pllcSysClock2Enable
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function enables the input clock to the RTI
 *     
 *   @return
 *      status
 *
 * =============================================================================
 */
extern CSL_Status pllcSysClock2Enable (
    void
);

/*
 * =============================================================================
 *   @func   comp0Isr
 *
 *   @arg
 *		NONE
 *
 *   @desc
 *     This is the ISR comp0Isr used for verifying Compare interrupt 0
 *
 *   @return
 *		NONE
 *
 * =============================================================================
 */
extern void comp0Isr ();

/*
 * =============================================================================
 *   @func   comp1Isr
 *
 *   @arg
 *		NONE
 *
 *   @desc
 *     This is the ISR comp1Isr used for verifying Compare interrupt1
 *
 *   @return
 *		NONE 
 *
 * =============================================================================
 */
extern interrupt void comp1Isr ();


/*
 * =============================================================================
 *   @func   pllc_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the pllc module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void  pllc_error_exit (
    void
);



/*
 * =============================================================================
 *   @func   intc_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the intc module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
void  intc_error_exit (
    void
);


/*
 * =============================================================================
 *   @func   rti_error_exit
 *
 *   @arg   
 *      NONE
 *
 *   @desc
 *     This function closes the rti module on error occurence
 *
 *  @return
 *      NONE
 *
 * =============================================================================
 */
extern void rti_error_exit (
    void
);


#ifdef __cplusplus
}
#endif


#endif /* _INTC_EXAMPLE_H_ */
