/* =============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *   file   cslr_hpi.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for HPI
 *          Reference: User Guide SPRU719
 *  ============================================================================
 */
#ifndef _CSLR_HPI_H_
#define _CSLR_HPI_H_

#include <cslr.h>
#include <tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint32 PWREMU_MGMT;
    volatile Uint32 GPIOINT;
    volatile Uint32 GPIOEN;
    volatile Uint32 GPIODIR1;
    volatile Uint32 GPIODAT1;
    volatile Uint32 GPIODIR2;
    volatile Uint32 GPIODAT2;
    volatile Uint32 GPIODIR3;
    volatile Uint32 GPIODAT3;
    volatile Uint8 RSVD0[8];
    volatile Uint32 HPIC;
    volatile Uint32 HPIAW;
    volatile Uint32 HPIAR;
} CSL_HpiRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_HpiRegs             *CSL_UhpiRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PID */

#define CSL_HPI_PID_TYPE_MASK (0x00FF0000u)
#define CSL_HPI_PID_TYPE_SHIFT (0x00000010u)
#define CSL_HPI_PID_TYPE_RESETVAL (0x00000001u)

#define CSL_HPI_PID_CLASS_MASK (0x0000FF00u)
#define CSL_HPI_PID_CLASS_SHIFT (0x00000008u)
#define CSL_HPI_PID_CLASS_RESETVAL (0x00000002u)

#define CSL_HPI_PID_REV_MASK (0x000000FFu)
#define CSL_HPI_PID_REV_SHIFT (0x00000000u)
#define CSL_HPI_PID_REV_RESETVAL (0x00000002u)

#define CSL_HPI_PID_RESETVAL (0x00010202u)

/* PWREMU_MGMT */


#define CSL_HPI_PWREMU_MGMT_SOFT_MASK (0x00000002u)
#define CSL_HPI_PWREMU_MGMT_SOFT_SHIFT (0x00000001u)
#define CSL_HPI_PWREMU_MGMT_SOFT_RESETVAL (0x00000000u)
/*----SOFT Tokens----*/
#define CSL_HPI_PWREMU_MGMT_SOFT_OFF (0x00000000u)
#define CSL_HPI_PWREMU_MGMT_SOFT_ON (0x00000001u)

#define CSL_HPI_PWREMU_MGMT_FREE_MASK (0x00000001u)
#define CSL_HPI_PWREMU_MGMT_FREE_SHIFT (0x00000000u)
#define CSL_HPI_PWREMU_MGMT_FREE_RESETVAL (0x00000000u)
/*----FREE Tokens----*/
#define CSL_HPI_PWREMU_MGMT_FREE_OFF (0x00000000u)
#define CSL_HPI_PWREMU_MGMT_FREE_ON (0x00000001u)

#define CSL_HPI_PWREMU_MGMT_RESETVAL (0x00000000u)

/* GPIOINT */


#define CSL_HPI_GPIOINT_GPINT_INV2_MASK (0x00040000u)
#define CSL_HPI_GPIOINT_GPINT_INV2_SHIFT (0x00000012u)
#define CSL_HPI_GPIOINT_GPINT_INV2_RESETVAL (0x00000000u)
/*----GPINT_INV2 Tokens----*/
#define CSL_HPI_GPIOINT_GPINT_INV2_DISABLE (0x00000000u)
#define CSL_HPI_GPIOINT_GPINT_INV2_ENABLE (0x00000001u)

#define CSL_HPI_GPIOINT_GPINT_INV1_MASK (0x00020000u)
#define CSL_HPI_GPIOINT_GPINT_INV1_SHIFT (0x00000011u)
#define CSL_HPI_GPIOINT_GPINT_INV1_RESETVAL (0x00000000u)
/*----GPINT_INV1 Tokens----*/
#define CSL_HPI_GPIOINT_GPINT_INV1_DISABLE (0x00000000u)
#define CSL_HPI_GPIOINT_GPINT_INV1_ENABLE (0x00000001u)

#define CSL_HPI_GPIOINT_GPINT_INV0_MASK (0x00010000u)
#define CSL_HPI_GPIOINT_GPINT_INV0_SHIFT (0x00000010u)
#define CSL_HPI_GPIOINT_GPINT_INV0_RESETVAL (0x00000000u)
/*----GPINT_INV0 Tokens----*/
#define CSL_HPI_GPIOINT_GPINT_INV0_DISABLE (0x00000000u)
#define CSL_HPI_GPIOINT_GPINT_INV0_ENABLE (0x00000001u)


#define CSL_HPI_GPIOINT_GPINT_EN2_MASK (0x00000004u)
#define CSL_HPI_GPIOINT_GPINT_EN2_SHIFT (0x00000002u)
#define CSL_HPI_GPIOINT_GPINT_EN2_RESETVAL (0x00000000u)
/*----GPINT_EN2 Tokens----*/
#define CSL_HPI_GPIOINT_GPINT_EN2_DISABLE (0x00000000u)
#define CSL_HPI_GPIOINT_GPINT_EN2_ENABLE (0x00000001u)

#define CSL_HPI_GPIOINT_GPINT_EN1_MASK (0x00000002u)
#define CSL_HPI_GPIOINT_GPINT_EN1_SHIFT (0x00000001u)
#define CSL_HPI_GPIOINT_GPINT_EN1_RESETVAL (0x00000000u)
/*----GPINT_EN1 Tokens----*/
#define CSL_HPI_GPIOINT_GPINT_EN1_DISABLE (0x00000000u)
#define CSL_HPI_GPIOINT_GPINT_EN1_ENABLE (0x00000001u)

#define CSL_HPI_GPIOINT_GPINT_EN0_MASK (0x00000001u)
#define CSL_HPI_GPIOINT_GPINT_EN0_SHIFT (0x00000000u)
#define CSL_HPI_GPIOINT_GPINT_EN0_RESETVAL (0x00000000u)
/*----GPINT_EN0 Tokens----*/
#define CSL_HPI_GPIOINT_GPINT_EN0_DISABLE (0x00000000u)
#define CSL_HPI_GPIOINT_GPINT_EN0_ENABLE (0x00000001u)

#define CSL_HPI_GPIOINT_RESETVAL (0x00000000u)

/* GPIOEN */


#define CSL_HPI_GPIOEN_GPIO_EN16_MASK (0x00010000u)
#define CSL_HPI_GPIOEN_GPIO_EN16_SHIFT (0x00000010u)
#define CSL_HPI_GPIOEN_GPIO_EN16_RESETVAL (0x00000000u)
/*----GPIO_EN16 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN16_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN16_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN15_MASK (0x00008000u)
#define CSL_HPI_GPIOEN_GPIO_EN15_SHIFT (0x0000000Fu)
#define CSL_HPI_GPIOEN_GPIO_EN15_RESETVAL (0x00000000u)
/*----GPIO_EN15 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN15_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN15_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN14_MASK (0x00004000u)
#define CSL_HPI_GPIOEN_GPIO_EN14_SHIFT (0x0000000Eu)
#define CSL_HPI_GPIOEN_GPIO_EN14_RESETVAL (0x00000000u)
/*----GPIO_EN14 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN14_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN14_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN13_MASK (0x00002000u)
#define CSL_HPI_GPIOEN_GPIO_EN13_SHIFT (0x0000000Du)
#define CSL_HPI_GPIOEN_GPIO_EN13_RESETVAL (0x00000000u)
/*----GPIO_EN13 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN13_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN13_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN12_MASK (0x00001000u)
#define CSL_HPI_GPIOEN_GPIO_EN12_SHIFT (0x0000000Cu)
#define CSL_HPI_GPIOEN_GPIO_EN12_RESETVAL (0x00000000u)
/*----GPIO_EN12 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN12_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN12_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN11_MASK (0x00000800u)
#define CSL_HPI_GPIOEN_GPIO_EN11_SHIFT (0x0000000Bu)
#define CSL_HPI_GPIOEN_GPIO_EN11_RESETVAL (0x00000000u)
/*----GPIO_EN11 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN11_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN11_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN10_MASK (0x00000400u)
#define CSL_HPI_GPIOEN_GPIO_EN10_SHIFT (0x0000000Au)
#define CSL_HPI_GPIOEN_GPIO_EN10_RESETVAL (0x00000000u)
/*----GPIO_EN10 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN10_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN10_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN9_MASK (0x00000200u)
#define CSL_HPI_GPIOEN_GPIO_EN9_SHIFT (0x00000009u)
#define CSL_HPI_GPIOEN_GPIO_EN9_RESETVAL (0x00000000u)
/*----GPIO_EN9 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN9_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN9_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN8_MASK (0x00000100u)
#define CSL_HPI_GPIOEN_GPIO_EN8_SHIFT (0x00000008u)
#define CSL_HPI_GPIOEN_GPIO_EN8_RESETVAL (0x00000000u)
/*----GPIO_EN8 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN8_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN8_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN7_MASK (0x00000080u)
#define CSL_HPI_GPIOEN_GPIO_EN7_SHIFT (0x00000007u)
#define CSL_HPI_GPIOEN_GPIO_EN7_RESETVAL (0x00000000u)
/*----GPIO_EN7 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN7_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN7_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN6_MASK (0x00000040u)
#define CSL_HPI_GPIOEN_GPIO_EN6_SHIFT (0x00000006u)
#define CSL_HPI_GPIOEN_GPIO_EN6_RESETVAL (0x00000000u)
/*----GPIO_EN6 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN6_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN6_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN5_MASK (0x00000020u)
#define CSL_HPI_GPIOEN_GPIO_EN5_SHIFT (0x00000005u)
#define CSL_HPI_GPIOEN_GPIO_EN5_RESETVAL (0x00000000u)
/*----GPIO_EN5 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN5_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN5_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN4_MASK (0x00000010u)
#define CSL_HPI_GPIOEN_GPIO_EN4_SHIFT (0x00000004u)
#define CSL_HPI_GPIOEN_GPIO_EN4_RESETVAL (0x00000000u)
/*----GPIO_EN4 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN4_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN4_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN3_MASK (0x00000008u)
#define CSL_HPI_GPIOEN_GPIO_EN3_SHIFT (0x00000003u)
#define CSL_HPI_GPIOEN_GPIO_EN3_RESETVAL (0x00000000u)
/*----GPIO_EN3 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN3_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN3_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN2_MASK (0x00000004u)
#define CSL_HPI_GPIOEN_GPIO_EN2_SHIFT (0x00000002u)
#define CSL_HPI_GPIOEN_GPIO_EN2_RESETVAL (0x00000000u)
/*----GPIO_EN2 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN2_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN2_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN1_MASK (0x00000002u)
#define CSL_HPI_GPIOEN_GPIO_EN1_SHIFT (0x00000001u)
#define CSL_HPI_GPIOEN_GPIO_EN1_RESETVAL (0x00000000u)
/*----GPIO_EN1 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN1_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN1_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_GPIO_EN0_MASK (0x00000001u)
#define CSL_HPI_GPIOEN_GPIO_EN0_SHIFT (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN0_RESETVAL (0x00000000u)
/*----GPIO_EN0 Tokens----*/
#define CSL_HPI_GPIOEN_GPIO_EN0_DISABLE (0x00000000u)
#define CSL_HPI_GPIOEN_GPIO_EN0_ENABLE (0x00000001u)

#define CSL_HPI_GPIOEN_RESETVAL (0x00000000u)

/* GPIODIR1 */

#define CSL_HPI_GPIODIR1_DIR_MASK (0xFFFFFFFFu)
#define CSL_HPI_GPIODIR1_DIR_SHIFT (0x00000000u)
#define CSL_HPI_GPIODIR1_DIR_RESETVAL (0x00000000u)
/*----DIR Tokens----*/
#define CSL_HPI_GPIODIR1_DIR_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR1_DIR_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR1_RESETVAL (0x00000000u)

/* GPIODAT1 */

#define CSL_HPI_GPIODAT1_DAT_MASK (0xFFFFFFFFu)
#define CSL_HPI_GPIODAT1_DAT_SHIFT (0x00000000u)
#define CSL_HPI_GPIODAT1_DAT_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT1_RESETVAL (0x00000000u)

/* GPIODIR2 */


#define CSL_HPI_GPIODIR2_DIR14_MASK (0x00004000u)
#define CSL_HPI_GPIODIR2_DIR14_SHIFT (0x0000000Eu)
#define CSL_HPI_GPIODIR2_DIR14_RESETVAL (0x00000000u)
/*----DIR14 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR14_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR14_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR13_MASK (0x00002000u)
#define CSL_HPI_GPIODIR2_DIR13_SHIFT (0x0000000Du)
#define CSL_HPI_GPIODIR2_DIR13_RESETVAL (0x00000000u)
/*----DIR13 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR13_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR13_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR12_MASK (0x00001000u)
#define CSL_HPI_GPIODIR2_DIR12_SHIFT (0x0000000Cu)
#define CSL_HPI_GPIODIR2_DIR12_RESETVAL (0x00000000u)
/*----DIR12 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR12_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR12_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR11_MASK (0x00000800u)
#define CSL_HPI_GPIODIR2_DIR11_SHIFT (0x0000000Bu)
#define CSL_HPI_GPIODIR2_DIR11_RESETVAL (0x00000000u)
/*----DIR11 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR11_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR11_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR10_MASK (0x00000400u)
#define CSL_HPI_GPIODIR2_DIR10_SHIFT (0x0000000Au)
#define CSL_HPI_GPIODIR2_DIR10_RESETVAL (0x00000000u)
/*----DIR10 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR10_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR10_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR9_MASK (0x00000200u)
#define CSL_HPI_GPIODIR2_DIR9_SHIFT (0x00000009u)
#define CSL_HPI_GPIODIR2_DIR9_RESETVAL (0x00000000u)
/*----DIR9 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR9_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR9_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR8_MASK (0x00000100u)
#define CSL_HPI_GPIODIR2_DIR8_SHIFT (0x00000008u)
#define CSL_HPI_GPIODIR2_DIR8_RESETVAL (0x00000000u)
/*----DIR8 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR8_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR8_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR7_MASK (0x00000080u)
#define CSL_HPI_GPIODIR2_DIR7_SHIFT (0x00000007u)
#define CSL_HPI_GPIODIR2_DIR7_RESETVAL (0x00000000u)
/*----DIR7 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR7_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR7_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR6_MASK (0x00000040u)
#define CSL_HPI_GPIODIR2_DIR6_SHIFT (0x00000006u)
#define CSL_HPI_GPIODIR2_DIR6_RESETVAL (0x00000000u)
/*----DIR6 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR6_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR6_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR5_MASK (0x00000020u)
#define CSL_HPI_GPIODIR2_DIR5_SHIFT (0x00000005u)
#define CSL_HPI_GPIODIR2_DIR5_RESETVAL (0x00000000u)
/*----DIR5 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR5_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR5_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR4_MASK (0x00000010u)
#define CSL_HPI_GPIODIR2_DIR4_SHIFT (0x00000004u)
#define CSL_HPI_GPIODIR2_DIR4_RESETVAL (0x00000000u)
/*----DIR4 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR4_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR4_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR3_MASK (0x00000008u)
#define CSL_HPI_GPIODIR2_DIR3_SHIFT (0x00000003u)
#define CSL_HPI_GPIODIR2_DIR3_RESETVAL (0x00000000u)
/*----DIR3 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR3_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR3_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR2_MASK (0x00000004u)
#define CSL_HPI_GPIODIR2_DIR2_SHIFT (0x00000002u)
#define CSL_HPI_GPIODIR2_DIR2_RESETVAL (0x00000000u)
/*----DIR2 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR2_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR2_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR1_MASK (0x00000002u)
#define CSL_HPI_GPIODIR2_DIR1_SHIFT (0x00000001u)
#define CSL_HPI_GPIODIR2_DIR1_RESETVAL (0x00000000u)
/*----DIR1 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR1_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR1_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_DIR0_MASK (0x00000001u)
#define CSL_HPI_GPIODIR2_DIR0_SHIFT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR0_RESETVAL (0x00000000u)
/*----DIR0 Tokens----*/
#define CSL_HPI_GPIODIR2_DIR0_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR2_DIR0_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR2_RESETVAL (0x00000000u)

/* GPIODAT2 */


#define CSL_HPI_GPIODAT2_DAT14_MASK (0x00004000u)
#define CSL_HPI_GPIODAT2_DAT14_SHIFT (0x0000000Eu)
#define CSL_HPI_GPIODAT2_DAT14_RESETVAL (0x00000000u)
/*----DAT14 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT14_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT14_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT13_MASK (0x00002000u)
#define CSL_HPI_GPIODAT2_DAT13_SHIFT (0x0000000Du)
#define CSL_HPI_GPIODAT2_DAT13_RESETVAL (0x00000000u)
/*----DAT13 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT13_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT13_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT12_MASK (0x00001000u)
#define CSL_HPI_GPIODAT2_DAT12_SHIFT (0x0000000Cu)
#define CSL_HPI_GPIODAT2_DAT12_RESETVAL (0x00000000u)
/*----DAT12 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT12_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT12_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT11_MASK (0x00000800u)
#define CSL_HPI_GPIODAT2_DAT11_SHIFT (0x0000000Bu)
#define CSL_HPI_GPIODAT2_DAT11_RESETVAL (0x00000000u)
/*----DAT11 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT11_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT11_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT10_MASK (0x00000400u)
#define CSL_HPI_GPIODAT2_DAT10_SHIFT (0x0000000Au)
#define CSL_HPI_GPIODAT2_DAT10_RESETVAL (0x00000000u)
/*----DAT10 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT10_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT10_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT9_MASK (0x00000200u)
#define CSL_HPI_GPIODAT2_DAT9_SHIFT (0x00000009u)
#define CSL_HPI_GPIODAT2_DAT9_RESETVAL (0x00000000u)
/*----DAT9 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT9_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT9_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT8_MASK (0x00000100u)
#define CSL_HPI_GPIODAT2_DAT8_SHIFT (0x00000008u)
#define CSL_HPI_GPIODAT2_DAT8_RESETVAL (0x00000000u)
/*----DAT8 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT8_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT8_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT7_MASK (0x00000080u)
#define CSL_HPI_GPIODAT2_DAT7_SHIFT (0x00000007u)
#define CSL_HPI_GPIODAT2_DAT7_RESETVAL (0x00000000u)
/*----DAT7 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT7_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT7_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT6_MASK (0x00000040u)
#define CSL_HPI_GPIODAT2_DAT6_SHIFT (0x00000006u)
#define CSL_HPI_GPIODAT2_DAT6_RESETVAL (0x00000000u)
/*----DAT6 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT6_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT6_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT5_MASK (0x00000020u)
#define CSL_HPI_GPIODAT2_DAT5_SHIFT (0x00000005u)
#define CSL_HPI_GPIODAT2_DAT5_RESETVAL (0x00000000u)
/*----DAT5 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT5_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT5_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT4_MASK (0x00000010u)
#define CSL_HPI_GPIODAT2_DAT4_SHIFT (0x00000004u)
#define CSL_HPI_GPIODAT2_DAT4_RESETVAL (0x00000000u)
/*----DAT4 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT4_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT4_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT3_MASK (0x00000008u)
#define CSL_HPI_GPIODAT2_DAT3_SHIFT (0x00000003u)
#define CSL_HPI_GPIODAT2_DAT3_RESETVAL (0x00000000u)
/*----DAT3 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT3_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT3_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT2_MASK (0x00000004u)
#define CSL_HPI_GPIODAT2_DAT2_SHIFT (0x00000002u)
#define CSL_HPI_GPIODAT2_DAT2_RESETVAL (0x00000000u)
/*----DAT2 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT2_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT2_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT1_MASK (0x00000002u)
#define CSL_HPI_GPIODAT2_DAT1_SHIFT (0x00000001u)
#define CSL_HPI_GPIODAT2_DAT1_RESETVAL (0x00000000u)
/*----DAT1 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT1_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT1_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_DAT0_MASK (0x00000001u)
#define CSL_HPI_GPIODAT2_DAT0_SHIFT (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT0_RESETVAL (0x00000000u)
/*----DAT0 Tokens----*/
#define CSL_HPI_GPIODAT2_DAT0_DISABLE (0x00000000u)
#define CSL_HPI_GPIODAT2_DAT0_ENABLE (0x00000001u)

#define CSL_HPI_GPIODAT2_RESETVAL (0x00000000u)

/* GPIODIR3 */

#define CSL_HPI_GPIODIR3_DIR31_MASK (0x80000000u)
#define CSL_HPI_GPIODIR3_DIR31_SHIFT (0x0000001Fu)
#define CSL_HPI_GPIODIR3_DIR31_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR30_MASK (0x40000000u)
#define CSL_HPI_GPIODIR3_DIR30_SHIFT (0x0000001Eu)
#define CSL_HPI_GPIODIR3_DIR30_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR29_MASK (0x20000000u)
#define CSL_HPI_GPIODIR3_DIR29_SHIFT (0x0000001Du)
#define CSL_HPI_GPIODIR3_DIR29_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR28_MASK (0x10000000u)
#define CSL_HPI_GPIODIR3_DIR28_SHIFT (0x0000001Cu)
#define CSL_HPI_GPIODIR3_DIR28_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR27_MASK (0x08000000u)
#define CSL_HPI_GPIODIR3_DIR27_SHIFT (0x0000001Bu)
#define CSL_HPI_GPIODIR3_DIR27_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR26_MASK (0x04000000u)
#define CSL_HPI_GPIODIR3_DIR26_SHIFT (0x0000001Au)
#define CSL_HPI_GPIODIR3_DIR26_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR25_MASK (0x02000000u)
#define CSL_HPI_GPIODIR3_DIR25_SHIFT (0x00000019u)
#define CSL_HPI_GPIODIR3_DIR25_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR24_MASK (0x01000000u)
#define CSL_HPI_GPIODIR3_DIR24_SHIFT (0x00000018u)
#define CSL_HPI_GPIODIR3_DIR24_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR23_MASK (0x00800000u)
#define CSL_HPI_GPIODIR3_DIR23_SHIFT (0x00000017u)
#define CSL_HPI_GPIODIR3_DIR23_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR22_MASK (0x00400000u)
#define CSL_HPI_GPIODIR3_DIR22_SHIFT (0x00000016u)
#define CSL_HPI_GPIODIR3_DIR22_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR21_MASK (0x00200000u)
#define CSL_HPI_GPIODIR3_DIR21_SHIFT (0x00000015u)
#define CSL_HPI_GPIODIR3_DIR21_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR20_MASK (0x00100000u)
#define CSL_HPI_GPIODIR3_DIR20_SHIFT (0x00000014u)
#define CSL_HPI_GPIODIR3_DIR20_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR19_MASK (0x00080000u)
#define CSL_HPI_GPIODIR3_DIR19_SHIFT (0x00000013u)
#define CSL_HPI_GPIODIR3_DIR19_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR18_MASK (0x00040000u)
#define CSL_HPI_GPIODIR3_DIR18_SHIFT (0x00000012u)
#define CSL_HPI_GPIODIR3_DIR18_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR17_MASK (0x00020000u)
#define CSL_HPI_GPIODIR3_DIR17_SHIFT (0x00000011u)
#define CSL_HPI_GPIODIR3_DIR17_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR16_MASK (0x00010000u)
#define CSL_HPI_GPIODIR3_DIR16_SHIFT (0x00000010u)
#define CSL_HPI_GPIODIR3_DIR16_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR15_MASK (0x00008000u)
#define CSL_HPI_GPIODIR3_DIR15_SHIFT (0x0000000Fu)
#define CSL_HPI_GPIODIR3_DIR15_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR14_MASK (0x00004000u)
#define CSL_HPI_GPIODIR3_DIR14_SHIFT (0x0000000Eu)
#define CSL_HPI_GPIODIR3_DIR14_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR13_MASK (0x00002000u)
#define CSL_HPI_GPIODIR3_DIR13_SHIFT (0x0000000Du)
#define CSL_HPI_GPIODIR3_DIR13_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR12_MASK (0x00001000u)
#define CSL_HPI_GPIODIR3_DIR12_SHIFT (0x0000000Cu)
#define CSL_HPI_GPIODIR3_DIR12_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR11_MASK (0x00000800u)
#define CSL_HPI_GPIODIR3_DIR11_SHIFT (0x0000000Bu)
#define CSL_HPI_GPIODIR3_DIR11_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR10_MASK (0x00000400u)
#define CSL_HPI_GPIODIR3_DIR10_SHIFT (0x0000000Au)
#define CSL_HPI_GPIODIR3_DIR10_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR9_MASK (0x00000200u)
#define CSL_HPI_GPIODIR3_DIR9_SHIFT (0x00000009u)
#define CSL_HPI_GPIODIR3_DIR9_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR8_MASK (0x00000100u)
#define CSL_HPI_GPIODIR3_DIR8_SHIFT (0x00000008u)
#define CSL_HPI_GPIODIR3_DIR8_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR7_MASK (0x00000080u)
#define CSL_HPI_GPIODIR3_DIR7_SHIFT (0x00000007u)
#define CSL_HPI_GPIODIR3_DIR7_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR6_MASK (0x00000040u)
#define CSL_HPI_GPIODIR3_DIR6_SHIFT (0x00000006u)
#define CSL_HPI_GPIODIR3_DIR6_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR5_MASK (0x00000020u)
#define CSL_HPI_GPIODIR3_DIR5_SHIFT (0x00000005u)
#define CSL_HPI_GPIODIR3_DIR5_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR4_MASK (0x00000010u)
#define CSL_HPI_GPIODIR3_DIR4_SHIFT (0x00000004u)
#define CSL_HPI_GPIODIR3_DIR4_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR3_MASK (0x00000008u)
#define CSL_HPI_GPIODIR3_DIR3_SHIFT (0x00000003u)
#define CSL_HPI_GPIODIR3_DIR3_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR2_MASK (0x00000004u)
#define CSL_HPI_GPIODIR3_DIR2_SHIFT (0x00000002u)
#define CSL_HPI_GPIODIR3_DIR2_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR1_MASK (0x00000002u)
#define CSL_HPI_GPIODIR3_DIR1_SHIFT (0x00000001u)
#define CSL_HPI_GPIODIR3_DIR1_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODIR3_DIR0_MASK (0x00000001u)
#define CSL_HPI_GPIODIR3_DIR0_SHIFT (0x00000000u)
#define CSL_HPI_GPIODIR3_DIR0_RESETVAL (0x00000000u)

/*----DIR Tokens----*/
#define CSL_HPI_GPIODIR3_DIR_INPUT (0x00000000u)
#define CSL_HPI_GPIODIR3_DIR_OUTPUT (0x00000001u)

#define CSL_HPI_GPIODIR3_RESETVAL (0x00000000u)

/* GPIODAT3 */

#define CSL_HPI_GPIODAT3_DAT31_MASK (0x80000000u)
#define CSL_HPI_GPIODAT3_DAT31_SHIFT (0x0000001Fu)
#define CSL_HPI_GPIODAT3_DAT31_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT30_MASK (0x40000000u)
#define CSL_HPI_GPIODAT3_DAT30_SHIFT (0x0000001Eu)
#define CSL_HPI_GPIODAT3_DAT30_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT29_MASK (0x20000000u)
#define CSL_HPI_GPIODAT3_DAT29_SHIFT (0x0000001Du)
#define CSL_HPI_GPIODAT3_DAT29_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT28_MASK (0x10000000u)
#define CSL_HPI_GPIODAT3_DAT28_SHIFT (0x0000001Cu)
#define CSL_HPI_GPIODAT3_DAT28_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT27_MASK (0x08000000u)
#define CSL_HPI_GPIODAT3_DAT27_SHIFT (0x0000001Bu)
#define CSL_HPI_GPIODAT3_DAT27_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT26_MASK (0x04000000u)
#define CSL_HPI_GPIODAT3_DAT26_SHIFT (0x0000001Au)
#define CSL_HPI_GPIODAT3_DAT26_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT25_MASK (0x02000000u)
#define CSL_HPI_GPIODAT3_DAT25_SHIFT (0x00000019u)
#define CSL_HPI_GPIODAT3_DAT25_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT24_MASK (0x01000000u)
#define CSL_HPI_GPIODAT3_DAT24_SHIFT (0x00000018u)
#define CSL_HPI_GPIODAT3_DAT24_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT23_MASK (0x00800000u)
#define CSL_HPI_GPIODAT3_DAT23_SHIFT (0x00000017u)
#define CSL_HPI_GPIODAT3_DAT23_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT22_MASK (0x00400000u)
#define CSL_HPI_GPIODAT3_DAT22_SHIFT (0x00000016u)
#define CSL_HPI_GPIODAT3_DAT22_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT21_MASK (0x00200000u)
#define CSL_HPI_GPIODAT3_DAT21_SHIFT (0x00000015u)
#define CSL_HPI_GPIODAT3_DAT21_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT20_MASK (0x00100000u)
#define CSL_HPI_GPIODAT3_DAT20_SHIFT (0x00000014u)
#define CSL_HPI_GPIODAT3_DAT20_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT19_MASK (0x00080000u)
#define CSL_HPI_GPIODAT3_DAT19_SHIFT (0x00000013u)
#define CSL_HPI_GPIODAT3_DAT19_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT18_MASK (0x00040000u)
#define CSL_HPI_GPIODAT3_DAT18_SHIFT (0x00000012u)
#define CSL_HPI_GPIODAT3_DAT18_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT17_MASK (0x00020000u)
#define CSL_HPI_GPIODAT3_DAT17_SHIFT (0x00000011u)
#define CSL_HPI_GPIODAT3_DAT17_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT16_MASK (0x00010000u)
#define CSL_HPI_GPIODAT3_DAT16_SHIFT (0x00000010u)
#define CSL_HPI_GPIODAT3_DAT16_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT15_MASK (0x00008000u)
#define CSL_HPI_GPIODAT3_DAT15_SHIFT (0x0000000Fu)
#define CSL_HPI_GPIODAT3_DAT15_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT14_MASK (0x00004000u)
#define CSL_HPI_GPIODAT3_DAT14_SHIFT (0x0000000Eu)
#define CSL_HPI_GPIODAT3_DAT14_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT13_MASK (0x00002000u)
#define CSL_HPI_GPIODAT3_DAT13_SHIFT (0x0000000Du)
#define CSL_HPI_GPIODAT3_DAT13_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT12_MASK (0x00001000u)
#define CSL_HPI_GPIODAT3_DAT12_SHIFT (0x0000000Cu)
#define CSL_HPI_GPIODAT3_DAT12_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT11_MASK (0x00000800u)
#define CSL_HPI_GPIODAT3_DAT11_SHIFT (0x0000000Bu)
#define CSL_HPI_GPIODAT3_DAT11_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT10_MASK (0x00000400u)
#define CSL_HPI_GPIODAT3_DAT10_SHIFT (0x0000000Au)
#define CSL_HPI_GPIODAT3_DAT10_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT9_MASK (0x00000200u)
#define CSL_HPI_GPIODAT3_DAT9_SHIFT (0x00000009u)
#define CSL_HPI_GPIODAT3_DAT9_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT8_MASK (0x00000100u)
#define CSL_HPI_GPIODAT3_DAT8_SHIFT (0x00000008u)
#define CSL_HPI_GPIODAT3_DAT8_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT7_MASK (0x00000080u)
#define CSL_HPI_GPIODAT3_DAT7_SHIFT (0x00000007u)
#define CSL_HPI_GPIODAT3_DAT7_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT6_MASK (0x00000040u)
#define CSL_HPI_GPIODAT3_DAT6_SHIFT (0x00000006u)
#define CSL_HPI_GPIODAT3_DAT6_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT5_MASK (0x00000020u)
#define CSL_HPI_GPIODAT3_DAT5_SHIFT (0x00000005u)
#define CSL_HPI_GPIODAT3_DAT5_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT4_MASK (0x00000010u)
#define CSL_HPI_GPIODAT3_DAT4_SHIFT (0x00000004u)
#define CSL_HPI_GPIODAT3_DAT4_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT3_MASK (0x00000008u)
#define CSL_HPI_GPIODAT3_DAT3_SHIFT (0x00000003u)
#define CSL_HPI_GPIODAT3_DAT3_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT2_MASK (0x00000004u)
#define CSL_HPI_GPIODAT3_DAT2_SHIFT (0x00000002u)
#define CSL_HPI_GPIODAT3_DAT2_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT1_MASK (0x00000002u)
#define CSL_HPI_GPIODAT3_DAT1_SHIFT (0x00000001u)
#define CSL_HPI_GPIODAT3_DAT1_RESETVAL (0x00000000u)

#define CSL_HPI_GPIODAT3_DAT0_MASK (0x00000001u)
#define CSL_HPI_GPIODAT3_DAT0_SHIFT (0x00000000u)
#define CSL_HPI_GPIODAT3_DAT0_RESETVAL (0x00000000u)


#define CSL_HPI_GPIODAT3_RESETVAL (0x00000000u)

/* HPIC */


#define CSL_HPI_HPIC_HPIA_RW_SEL_MASK (0x00000800u)
#define CSL_HPI_HPIC_HPIA_RW_SEL_SHIFT (0x0000000Bu)
#define CSL_HPI_HPIC_HPIA_RW_SEL_RESETVAL (0x00000000u)
/*----HPIA_RW_SEL Tokens----*/
#define CSL_HPI_HPIC_HPIA_RW_SEL_HPIA_R (0x00000000u)
#define CSL_HPI_HPIC_HPIA_RW_SEL_HPIA_W (0x00000001u)

#define CSL_HPI_HPIC_LB_MODE_MASK (0x00000400u)
#define CSL_HPI_HPIC_LB_MODE_SHIFT (0x0000000Au)
#define CSL_HPI_HPIC_LB_MODE_RESETVAL (0x00000000u)
/*----LB_MODE Tokens----*/
#define CSL_HPI_HPIC_LB_MODE_DISABLE_LB (0x00000000u)
#define CSL_HPI_HPIC_LB_MODE_ENABLE_LB (0x00000001u)

#define CSL_HPI_HPIC_DUAL_HPIA_MASK (0x00000200u)
#define CSL_HPI_HPIC_DUAL_HPIA_SHIFT (0x00000009u)
#define CSL_HPI_HPIC_DUAL_HPIA_RESETVAL (0x00000000u)
/*----DUAL_HPIA Tokens----*/
#define CSL_HPI_HPIC_DUAL_HPIA_DISABLE (0x00000000u)
#define CSL_HPI_HPIC_DUAL_HPIA_ENABLE (0x00000001u)

#define CSL_HPI_HPIC_HWOB_STAT_MASK (0x00000100u)
#define CSL_HPI_HPIC_HWOB_STAT_SHIFT (0x00000008u)
#define CSL_HPI_HPIC_HWOB_STAT_RESETVAL (0x00000000u)

#define CSL_HPI_HPIC_HPI_RST_MASK (0x00000080u)
#define CSL_HPI_HPIC_HPI_RST_SHIFT (0x00000007u)
#define CSL_HPI_HPIC_HPI_RST_RESETVAL (0x00000001u)

#define CSL_HPI_HPIC_RESET_MASK (0x00000040u)
#define CSL_HPI_HPIC_RESET_SHIFT (0x00000006u)
#define CSL_HPI_HPIC_RESET_RESETVAL (0x00000001u)

#define CSL_HPI_HPIC_XHPIA_MASK (0x00000020u)
#define CSL_HPI_HPIC_XHPIA_SHIFT (0x00000005u)
#define CSL_HPI_HPIC_XHPIA_RESETVAL (0x00000000u)

#define CSL_HPI_HPIC_FETCH_MASK (0x00000010u)
#define CSL_HPI_HPIC_FETCH_SHIFT (0x00000004u)
#define CSL_HPI_HPIC_FETCH_RESETVAL (0x00000000u)

#define CSL_HPI_HPIC_HRDY_MASK (0x00000008u)
#define CSL_HPI_HPIC_HRDY_SHIFT (0x00000003u)
#define CSL_HPI_HPIC_HRDY_RESETVAL (0x00000000u)

#define CSL_HPI_HPIC_HINT_MASK (0x00000004u)
#define CSL_HPI_HPIC_HINT_SHIFT (0x00000002u)
#define CSL_HPI_HPIC_HINT_RESETVAL (0x00000000u)
/*----HINT Tokens----*/
#define CSL_HPI_HPIC_HINT_DISABLE (0x00000001u)
#define CSL_HPI_HPIC_HINT_ENABLE (0x00000001u)

#define CSL_HPI_HPIC_DSP_INT_MASK (0x00000002u)
#define CSL_HPI_HPIC_DSP_INT_SHIFT (0x00000001u)
#define CSL_HPI_HPIC_DSP_INT_RESETVAL (0x00000000u)
/*----DSP_INT Tokens----*/
#define CSL_HPI_HPIC_DSP_INT_DISABLE (0x00000000u)
#define CSL_HPI_HPIC_DSP_INT_ENABLE (0x00000001u)

#define CSL_HPI_HPIC_HWOB_MASK (0x00000001u)
#define CSL_HPI_HPIC_HWOB_SHIFT (0x00000000u)
#define CSL_HPI_HPIC_HWOB_RESETVAL (0x00000000u)
/*----HWOB Tokens----*/
#define CSL_HPI_HPIC_HWOB_DISABLE (0x00000000u)
#define CSL_HPI_HPIC_HWOB_ENABLE (0x00000001u)

#define CSL_HPI_HPIC_RESETVAL (0x000000C0u)

/* HPIAW */

#define CSL_HPI_HPIAW_HPIAW_MASK (0xFFFFFFFFu)
#define CSL_HPI_HPIAW_HPIAW_SHIFT (0x00000000u)
#define CSL_HPI_HPIAW_HPIAW_RESETVAL (0x00000000u)

#define CSL_HPI_HPIAW_RESETVAL (0x00000000u)

/* HPIAR */

#define CSL_HPI_HPIAR_HPIAR_MASK (0xFFFFFFFFu)
#define CSL_HPI_HPIAR_HPIAR_SHIFT (0x00000000u)
#define CSL_HPI_HPIAR_HPIAR_RESETVAL (0x00000000u)

#define CSL_HPI_HPIAR_RESETVAL (0x00000000u)

#endif
