/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_chipInit.c
 *
 *  @brief File for functional layer of CSL API @a CSL_chipInit()
 *
 * Modification 
 *    - modified on: 23/11/2004
 *    - reason: Created the sources
 *
 * 
 * @author Ramitha Mathew.
 */

#include <csl_types.h>
#include <csl_error.h>
#include <csl_chip.h>

/** ============================================================================
 *   @n@b CSL_chipInit
 *
 *   @b Description
 *   @n This is the initialization function for the CHIP CSL. The function
 *      must be called before calling any other API from this CSL. This
 *      function does not modify any registers or check status. It returns 
 *      status CSL_SOK. It has been kept for the future use.
 *
 *   @b Arguments
 *   @verbatim
        pContext    Pointer to module-context. As CHIP doesn't have
                    any context based information user is expected to pass NULL.
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Always returns
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  The CSL for CHIP is initialized
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim
            CSL_chipInit (NULL);
     @endverbatim
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_chipInit, ".text:csl_section:chip");

CSL_Status	CSL_chipInit (
        CSL_ChipContext	*pContext
)
{
	pContext = pContext;
	return CSL_SOK;
}

