/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_chipReadReg.c
 *
 *  @brief File for functional layer of CSL API @a CSL_chipReadReg()
 *
 * Modification 
 *    - modified on: 25/11/2004
 *    - reason: Created the sources
 *
 * 
 * @author Ramitha Mathew.
 */

#include <csl_chip.h>

/* assembly code to read memory mapped registers */
extern Uint32            CSL_readMMR (
    CSL_ChipReg
);

/* assembly code to read non memory mapped registers */
extern Uint32	CSL_read_AMR (
);
extern Uint32	CSL_read_CSR (
);
extern Uint32	CSL_read_FADCR (
);
extern Uint32	CSL_read_FAUCR (
);
extern Uint32	CSL_read_FMCR (
);



/** ============================================================================
 *   @n@b CSL_chipReadReg
 * 
 *   @b Description 
 *   @n This function could be used to read the CHIP registers. The
 *      register that can be specified could be one of those enumerated
 *      in CSL_ChipReg.
 *
 *   @b Arguments
     @verbatim
        regId - This is the register id specified for the register 
                through the enum       
     @endverbatim
 *
 *   <b> Return Value </b>  
 *   @li Uint32 - The value read from the register
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_chipInit () must be called
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n None
 *
 *   @b Example:
     @verbatim
  
     Uint32 readValue;
     readValue = CSL_chipReadReg (CSL_CHIP_REG_CSR);
  
 *   @endverbatim 
 *   ==========================================================================
 */
#pragma CODE_SECTION (CSL_chipReadReg, ".text:csl_section:chip");

Uint32 CSL_chipReadReg (
    CSL_ChipReg	regId
)
{
    Uint32                   readValue;

    /* Identifying whether memory mapped or non memory mapped register */
    if ((regId % 2) == NULL)
        return (CSL_readMMR (regId));
    else {
        switch (regId) {
        case 1:
            readValue = CSL_read_AMR ();
            break;
        case 3:
            readValue = CSL_read_CSR ();
            break;
        case 5:
            readValue = CSL_read_FADCR ();
            break;
        case 7:
            readValue = CSL_read_FAUCR ();
            break;
        case 9:
            readValue = CSL_read_FMCR ();
            break;
        default:
            break;
        }
    }
    return (readValue);
}
