/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_chipWriteReg.c
 *
 *  @brief File for functional layer of CSL API @a CSL_chipWriteReg()
 *
 * Modification 
 *    - modified on: 25/11/2004
 *    - reason: Created the sources
 *
 * 
 * @author Ramitha Mathew.
 */

#include <csl_chip.h>

extern Uint32	CSL_writeMMR (
    CSL_ChipReg,
    Uint32
);
extern Uint32	CSL_write_AMR (
    Uint32
);
extern Uint32   CSL_write_CSR (
    Uint32
);
extern Uint32   CSL_write_FADCR (
    Uint32
);
extern Uint32   CSL_write_FAUCR (
    Uint32
);
extern Uint32   CSL_write_FMCR (
    Uint32
);

/** ============================================================================
 *   @n@b CSL_chipWriteReg
 * 
 *   @b Description 
 *   @n This function could be used to write to the CHIP registers. The
 *      register that can be specified could be one of those enumerated
 *      in CSL_ChipReg.
 *
 *   @b Arguments
     @verbatim
        regId - This is the register id specified for the register 
                through the enum
        val   - Value to be written into the register
     @endverbatim
 *
 *   <b> Return Value </b>  
 *   @li Uint32 - The value in the register before the new value being written
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_chipInit () must be called
 *
 *   <b> Post Condition </b>
 *   @n  The specified register will be modified
 *
 *   @b Modifies
 *   @n The specified register will be modified
 *
 *   @b Example:
     @verbatim
  
       Uint32 oldRegVal;
        oldRegVal = CSL_chipWriteReg ( CSL_CHIP_REG_PCER, newRegVal);
  
     @endverbatim 
 */

#pragma CODE_SECTION (CSL_chipWriteReg, ".text:csl_section:chip");

Uint32 CSL_chipWriteReg (
    CSL_ChipReg 	regId,
    Uint32 			val
)
{
    Uint32		preValue;

    /* Identifying whether memory mapped or non memory mapped register */

    if ((regId % 2) == NULL)
        return (CSL_writeMMR (regId, val));
    else {
        switch (regId) {
	        case 1:
	            preValue = CSL_write_AMR (val);
	            break;
	        case 3:
	            preValue = CSL_write_CSR (val);
	            break;
	        case 5:
	            preValue = CSL_write_FADCR (val);
	            break;
	        case 7:
	            preValue = CSL_write_FAUCR (val);
	            break;
	        case 9:
	            preValue = CSL_write_FMCR (val);
	            break;
	        default:
	            break;
        }
    }
    return (preValue);
}
