/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_dmaxGetHwSetup1dParam.c
 *
 *  @brief File for functional layer of CSL API @a 
 *					CSL_dmaxGetHwSetup1dXFRParamEntry()
 *
 *  Description
 *    - The @a CSL_dmaxGetHwSetup1dXFRParamEntry() 
 *      function definition & it's associated functions
 *
 *  Creation on: 11/July/2007
 *    - Reason: To support additional features.
 * 
 *  @author NG
 */

#include <csl_dmax.h>
/** =======================================================================
 *   @n@b CSL_dmaxGetHwSetup1dXFRParamEntry
 *
 *   @b Description
 *   @n This function initializes the device registers with the appropriate
 *      values provided through the HwSetup Data structure. After the 
 *      Setup is completed, the device is ready for  operation.      
 *      For information passed through the HwSetup Data structure refer
 *   @a CSL_dmaxHwSetup.
 *
 *   @b Arguments
 *   @verbatim
 *    
 *          paramEntry  Pointer to Prameter Table Entry where data 
 *						is to be stored
 *
 *          setup  		Pointer to a dmax FIFO Transfer Setup Object
 *           
 *   @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Successful completion of hardware     
 *                                    setup
 *   @li                    CSL_ESYS_ INVPARAMS - Hardware structure is  
 *                                    not properly initialized
 *   @li                    CSL_ESYS_ BADHANDLE - Invalid CSL handle
 *
 *
 *   <b> Pre Condition </b>
 *   @n  Both CSL_dmaxInit() and a CSL_dmaxOpen() must be called
 *
 *   <b> Post Condition </b>
 *   @n  DMAX registers are configured 
 *
 *   @b  Modifies
 *   @n  DMAX registers
 *
 *   @b Example
 *   @verbatim  
      CSL_DmaxParameterEntry 	paramEntry;
      CSL_Dmax1dParameterSetup 	hwSetup;
      
      hwSetup.linearReload0 = paramEntry[0];
      .
      .
      hwSetup.delayTabPtr1  = paramEntry[9];
    
      CSL_dmaxGetHwSetup1dXFRParamEntry(hDmax, &hwSetup);
     @endverbatim
 * 
 * ============================================================================
 */
#pragma CODE_SECTION \
    (CSL_dmaxGetHwSetup1dXFRParamEntry, ".text:csl_section:dmax");

CSL_Status CSL_dmaxGetHwSetup1dXFRParamEntry (
    CSL_DmaxParameterEntry 		*paramEntry,
    CSL_Dmax1dParameterSetup 	*setup
)
{
    Uint32		*tmpPtr = (Uint32 *) paramEntry;

    setup->event = CSL_FEXTR(tmpPtr[0],31,24);
    setup->tcc = CSL_FEXTR(tmpPtr[0],23,16);
    setup->nburst = CSL_FEXTR(tmpPtr[0],7,4);
    setup->tcint = CSL_FEXTR(tmpPtr[0],0,0);

    setup->srcAddr = tmpPtr[1];
    setup->dstAddr = tmpPtr[2];
    
    setup->burstlen = CSL_FEXTR(tmpPtr[3],23,16);
    setup->count = CSL_FEXTR(tmpPtr[3],15,0);

    return CSL_SOK;
}


