/*  ============================================================================ 
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_dmaxGetHwSetupSpiParam.c
 *
 *  @brief File for functional layer of CSL API @a 
 *					CSL_dmaxGetHwSetupSpiXFRParamEntry()
 *
 *  Description
 *    - The @a CSL_dmaxGetHwSetupSpiXFRParamEntry() 
 *      function definition & it's associated functions
 *
 *  Creation on: 11/July/2007
 *    - Reason: To support additional features.
 * 
 *  @author NG
 */

#include <csl_dmax.h>
/** =======================================================================
 *   @n@b CSL_dmaxGetHwSetupSpiXFRParamEntry
 *
 *   @b Description
 *   @n This function initializes the device registers with the appropriate
 *      values provided through the HwSetup Data structure. After the 
 *      Setup is completed, the device is ready for  operation.      
 *      For information passed through the HwSetup Data structure refer
 *   @a CSL_dmaxHwSetup.
 *
 *   @b Arguments
 *   @verbatim
 *    
 *          paramEntry  Pointer to Prameter Table Entry where data 
 *						is to be stored
 *
 *          setup  		Pointer to a dmax FIFO Transfer Setup Object
 *           
 *   @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Successful completion of hardware     
 *                                    setup
 *   @li                    CSL_ESYS_ INVPARAMS - Hardware structure is  
 *                                    not properly initialized
 *   @li                    CSL_ESYS_ BADHANDLE - Invalid CSL handle
 *
 *
 *   <b> Pre Condition </b>
 *   @n  Both CSL_dmaxInit() and a CSL_dmaxOpen() must be called
 *
 *   <b> Post Condition </b>
 *   @n  DMAX registers are configured 
 *
 *   @b  Modifies
 *   @n  DMAX registers
 *
 *   @b Example
 *   @verbatim  
      CSL_DmaxParameterEntry 	paramEntry;
      CSL_DmaxSpiParameterSetup	hwSetup;
      
      hwSetup.linearReload0 = paramEntry[0];
      .
      .
      hwSetup.delayTabPtr1  = paramEntry[9];
    
      CSL_dmaxGetHwSetupSpiXFRParamEntry(hDmax, &hwSetup);
     @endverbatim
 * 
 * ============================================================================
 */
#pragma CODE_SECTION \
    (CSL_dmaxGetHwSetupSpiXFRParamEntry, ".text:csl_section:dmax");

CSL_Status CSL_dmaxGetHwSetupSpiXFRParamEntry (
    CSL_DmaxParameterEntry 		*paramEntry,
    CSL_DmaxSpiParameterSetup 	*setup
)
{
    Uint32		*tmpPtr = (Uint32 *) paramEntry;

    setup->srcAddr = tmpPtr[0];
    setup->dstAddr = tmpPtr[1];
    setup->pp = CSL_FEXTR(tmpPtr[2],31,31);
    setup->count = CSL_FEXTR(tmpPtr[2],15,0);
    setup->rldCount = tmpPtr[3];
    setup->srcRldAddr0 = tmpPtr[4];
    setup->dstRldAddr0 = tmpPtr[5];
    setup->srcRldAddr1 = tmpPtr[6];
    setup->dstRldAddr1 = tmpPtr[7];

    return CSL_SOK;
}


