/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_dmaxHwSetupSpiParam.c
 *
 *  @brief File for functional layer of CSL API @a CSL_dmaxHwSetupSpiParam()
 *
 *  Description
 *    - The @a CSL_dmaxHwSetupSpiParam() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 11/March/2005
 *    - Reason: created the sources
 * 
 *  @author asr.
 */

#include <csl_dmax.h>
/** =======================================================================
 *   @n@b CSL_dmaxHwSetupSpiParam
 *
 *   @b Description
 *   @n This function initializes the device registers with the appropriate
 *      values provided through the HwSetup Data structure. After the 
 *      Setup is completed, the device is ready for  operation.      
 *      For information passed through the HwSetup Data structure refer
 *   @a CSL_dmaxHwSetup.
 *
 *   @b Arguments
 *   @verbatim
 *    
 *          paramEntry  Pointer to Prameter Table Entry where data is to be 
 *						stored
 *          setup  		Pointer to a dmax FIFO Transfer Setup Object
 *           
 *   @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Successful completion of hardware     
 *                                    setup
 *   @li                    CSL_ESYS_ INVPARAMS - Hardware structure is not 
 *                                    properly initialized
 *   @li                    CSL_ESYS_ BADHANDLE - Invalid CSL handle
 *
 *
 *   <b> Pre Condition </b>
 *   @n  Both CSL_dmaxInit() and a CSL_dmaxOpen() must be called
 *
 *   <b> Post Condition </b>
 *   @n  DMAX registers are configured 
 *
 *   @b  Modifies
 *   @n  DMAX registers
 *
 *   @b Example
 *   @verbatim  
      CSL_DmaxParameterEntry 	paramEntry;
      CSL_dmaxHwSetup 			hwSetup;
      
      hwSetup.linearReload0  = 0x10000100;
      .
      .
      hwSetup.count0         = 3;
    
      CSL_dmaxHwSetupSpiXFRParameterEntry(hDmax, &hwSetup);
     @endverbatim
 * 
 * ============================================================================
 */
#pragma CODE_SECTION \
    (CSL_dmaxSetupSpiXFRParameterEntry, ".text:csl_section:dmax");
CSL_Status CSL_dmaxSetupSpiXFRParameterEntry (
    CSL_DmaxParameterEntry 		*paramEntry,
    CSL_DmaxSpiParameterSetup	*setup
)
{
    Uint32		*tmpPtr = (Uint32 *) paramEntry;

    tmpPtr[0] = setup->srcAddr;
    tmpPtr[1] = setup->dstAddr;
    tmpPtr[2] = (CSL_FMKR (31,31, setup->pp) | CSL_FMKR (15,0, setup->count));
    tmpPtr[3] = setup->rldCount;
    tmpPtr[4] = setup->srcRldAddr0;
    tmpPtr[5] = setup->dstRldAddr0;
    tmpPtr[6] = setup->srcRldAddr1;
    tmpPtr[7] = setup->dstRldAddr1;

    return CSL_SOK;
}
