/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_dmaxInit.c
 *
 *  @brief  File for functional layer of CSL API @a CSL_dmaxInit()
 *
 *  Description
 *    - The @a CSL_dmaxInit() function definition & it's associated functions
 *
 *  Modification 1
 *    - Modified on: 11/Mar/2005
 *    - Reason: created the sources
 * 
 *  @author asr.
 */


#include <csl_dmax.h>

CSL_DmaxResourceAlloc    CslDmaxAlloc = { 	  {32, 0}
											, {32, 0}
											, {11, 0}
											, {11, 0}
										};
Uint32	CSL_dmaxGetNextFreeParamEntry (
    Uint32,
    CSL_Status*
);
/** ============================================================================
 *   @n@b CSL_dmaxInit
 *
 *   @b Description
 *   @n This is the initialization function for the DMAX CSL. This function 
 *      needs to be called before any other DMAX CSL functions are called. 
 *      This function does not modify any registers. It Initilizes all the
 *      events and parameters of High and low priorities and with zero's.
 *      It returns status CSL_SOK.      
 *
 *   @b Arguments
 *   @verbatim
 *          pContext   Context information for the instance. Should be NULL
 *   @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Always returns
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_sysInit() must be called. 
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim
 *     
 *
 *       CSL_dmaxInit(NULL);
  *   @endverbatim
 *  ===========================================================================
 */

#pragma CODE_SECTION (CSL_dmaxInit, ".text:csl_section:dmax");

CSL_Status CSL_dmaxInit (
    CSL_DmaxContext 	*pContext
)
{
    /* To remove compiler warning/remarks */
    pContext = pContext;

    CslDmaxAlloc.cslDmaxHpecrAlloc.allocMap = 0;
    CslDmaxAlloc.cslDmaxLpecrAlloc.allocMap = 0;
    CslDmaxAlloc.cslDmaxHpptAlloc.allocMap = 0;
    CslDmaxAlloc.cslDmaxLpptAlloc.allocMap = 0;

    return CSL_SOK;
}
