/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_emifClose.c
 *
 *  @path $(CSLPATH)\emif\src\csl_emifClose.c
 *
 *  @brief File for functional layer of CSL API @a CSL_emifClose()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  1-Dec-2004 author File Created.	                 
 * =============================================================================
 */

#include <csl_emif.h>

/** ============================================================================
 *   @n@b CSL_emifClose
 *
 *   @b Description
 *   @n This function marks that CSL for the EMIF instance is closed. CSL for 
 *		the EMIF instance need to be reopened before using any EMIF CSL API 
 *		again.
 *
 *   @b Arguments
 *   @verbatim
        hEmif 			Handle to EMIF
        
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - EMIF is closed Successfully
 *   @li                    CSL_ESYS_BADHANDLE  - The handle passed is invalid
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @li  CSL for the EMIF instance is closed
 *
 *   @b Modifies
 *   @n  System data object
 * 
 *
 *   @b Example
 *   @verbatim
    CSL_EmifHandle  hEmif;
     ..
     
     status = CSL_emifClose (hEmif);
        
     ..
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_emifClose, ".text:csl_section:emif");
CSL_Status CSL_emifClose (
    /*
     * Pointer to the object that holds reference to the
     * instance of EMIF requested after the call
     */
    CSL_EmifHandle hEmif
)
{
    CSL_Status               status;

    if (hEmif != NULL) {
        hEmif->regs = (CSL_EmifRegsOvly) NULL;
        hEmif->emifNum = (CSL_InstNum) - 1;
        status = CSL_SOK;
    }
    else {
        status = CSL_ESYS_BADHANDLE;
    }

    return status;
}
