/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_emifInit.c
 *
 *  @path $(CSLPATH)\emif\src
 *
 *  @brief File for functional layer of CSL API @a CSL_emifInit()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  10-Sep-2004 author  File Created.
 * =============================================================================
 */

#include <csl_emif.h>

/** ============================================================================
 *   @n@b CSL_emifInit
 *
 *   @b Description
 *   @n This is the initialization function for the emif CSL. The function
 *      must be called before calling any other API from this CSL. This 
 *      function does not modify any registers or check status. It returns 
 *      status CSL_SOK. It has been kept for future use.
 *
 *   @b Arguments
 *   @verbatim
        pContext    Context information to EMIF
        
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                        CSL_SOK - Always returns
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_sysInit() must be called. 
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim
            CSL_Status  status;
            ...
            status = CSL_emifInit(NULL);
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_emifInit, ".text:csl_section:emif");
CSL_Status CSL_emifInit (
    /*
     * EMIF specific context information
     */
    CSL_EmifContext * pContext
)
{
    /* Added following code to avoid compiler warning */
    pContext = pContext;

    return CSL_SOK;
}
