/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file csl_i2cClose.c
 *
 *  @brief File for functional layer of CSL API @a CSL_i2cClose()
 *
 *  Description
 *    - The @a CSL_i2cClose() function definition & it's associated functions
 *
 *  Modification 1
 *    - Created on: 18/1/2005
 *    - Reason: created the sources
 * 
 *    @author Ramitha Mathew.
 */


#include <csl_i2c.h>

/** ============================================================================
 *   @n@b CSL_i2cClose
 *
 *   @b Description
 *   @n This function closes the specified instance of I2C.
 *
 *   @b Arguments
     @verbatim
            hI2c  Handle to the I2C instance
     @endverbatim  
 *     
 *   <b> Return Value </b> CSL_Status 
 *   @li               CSL_SOK  - I2C close successful 
 *   @li               CSL_ESYS_BADHANDLE - Invalid handle
 *     
 *      
 *   <b> Pre Condition </b>
 *   @n  i2c must have opened properly
 *
 *   <b> Post Condition </b>
 *   @n  CSL for the I2C instance is closed
 *
 *   @b Modifies
 *   @n CSL_I2cObj structure values for the instance
 * 
 *   @b Example
     @verbatim
     
        CSL_i2cClose (hI2c);
       
     @endverbatim  
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_i2cClose, ".text:csl_section:i2c");

CSL_Status CSL_i2cClose (
    CSL_I2cHandle   hI2c
)
{
    CSL_Status  status;

    if (hI2c != CSL_I2C_BADHANDLE) {
        hI2c->regs = (CSL_I2cRegsOvly) NULL;
        hI2c->perNum = (CSL_InstNum) - 1;
        status = CSL_SOK;
    }
    else {
        status = CSL_ESYS_BADHANDLE;
    }

    return status;
}
