/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/** @file csl_i2cInit.c
 *
 *  @brief  File for functional layer of CSL API @a CSL_i2cInit()
 *
 *  Description
 *    - The @a CSL_i2cInit() function definition & it's associated functions
 *
 *  Modification 1
 *    - Modified on: 18/1/2005
 *    - Reason: created the sources
 * 
 *  @author Ramitha Mathew.
 */


#include <csl_i2c.h>

/** ============================================================================
 *   @n@b CSL_i2cInit
 *
 *   @b Description
 *   @n This is the initialization function for the I2C. This function is
 *      idempotent in that calling it many times is same as calling it once.
 *      This function doesn't affect the H/W.      
 *
 *   @b Arguments
     @verbatim
            pContext   Context information for the instance. Should be NULL
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Always returns
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_sysInit() must be called. 
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim
      ...      
         CSL_i2cInit();
      
 *   @endverbatim
 *  ===========================================================================
 */

#pragma CODE_SECTION (CSL_i2cInit, ".text:csl_section:i2c");

CSL_Status CSL_i2cInit (
    CSL_I2cContext      *pContext
)
{
    /* To remove compiler warning/remarks */
    pContext = pContext;
    return CSL_SOK;
}
