/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_icacheClose.c
 *
 *   @path  $(CSLPATH)\ipmodules\icache\src
 *
 *   @desc  L1P I-cache CSL implementation 
 *  ===========================================================================
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 *
 * =============================================================================
 */


#include <csl_icache.h>

/** ============================================================================
 *   @n@b CSL_icacheClose
 *
 *   @b Description
 *   @n This function releases the instance of the icache.
 *      
 *   @b Arguments
 *   @verbatim
            hIcache          Handle to the icache instance 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Close successful
 *   @li                    CSL_ESYS_BADHANDLE - Invalid handle
 *
 *   <b> Pre Condition </b>
 *   @n  icache would have opened properly
 *
 *   <b> Post Condition </b>
 *   @n  Icache instance is closed and its usage is illegal until next open
 *
 *   @b Modifies
 *   @n  peripheral data object
 *            
 *   @b Example
 *   @verbatim
            status = CSL_icacheClose (hIcache);
    @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_icacheClose, ".text:csl_section:icache");

CSL_Status CSL_icacheClose (
    CSL_IcacheHandle    hIcache
)
{
    CSL_Status  status;

    status = CSL_SOK;

    if (hIcache != NULL) {
        hIcache->regs = (CSL_IcacheRegsOvly) NULL;
        hIcache->icacheNum = (CSL_InstNum) - 1;
    }
    else {
        status = CSL_ESYS_BADHANDLE;
    }

    return status;
}
