/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_icacheHwSetup.c
 *
 *   @path  $(CSLPATH)\ipmodules\icache\src
 *
 *   @desc  L1P I-cache CSL implementation 
 */


/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 *
 * =============================================================================
 */


#include <csl_icache.h>


/** ============================================================================
 *   @n@b CSL_icacheHwSetup
 *
 *   @b Description
 *   @n This function initializes the L1P I-cache hardware to a known state. 
 *
 *   @b Arguments
 *   @verbatim

            hIcache         Handle to the L1P I-cache instance 
            hwSetup         Pointer to hardware setup structure
 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Hardware setup successful
 *   @li                    CSL_ESYS_BADHANDLE - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS - Invalid parameter 
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_icacheInit () and CSL_icacheOpen () must be called
 *
 *   <b> Post Condition </b>
 *   @n  The hardware set up structure will be populated with values for the 
 *       setup parameters

 *   @b Modifies
 *   @n Hardware registers
 *
 *   @b Example
 *   @verbatim
            CSL_IcacheHandle    hIcache;
            CSL_IcacheHwSetup   icacheHwsetup;
                        
            icacheHwsetup = CSL_ICACHE_HWSETUP_DEFAULTS;                               
            CSL_icacheHwSetup (hIcache, &icacheHwsetup);
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_icacheHwSetup, ".text:csl_section:icache");

CSL_Status CSL_icacheHwSetup (
    CSL_IcacheHandle    hIcache,
    CSL_IcacheHwSetup   *hwSetup
)
{
    CSL_Status  status = CSL_SOK;

    if (hIcache == NULL)
        return CSL_ESYS_BADHANDLE;


    if (hwSetup == NULL)
        return CSL_ESYS_INVPARAMS;

    status = _CSL_icacheConfg (hwSetup->mode, hwSetup->ramAccessPrio);
    
    return status;
}
