/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_icacheHwSetupRaw.c
 *
 *   @path  $(CSLPATH)\ipmodulesicache\src
 *
 *   @desc  L1P I-cache CSL implementation.
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 *
 * =============================================================================
 */

#include <csl_icache.h>
#include <csl_chip.h>


/** ============================================================================
 *   @n@b CSL_icacheHwSetupRaw
 *
 *   @b Description
 *   @n This function configures the icache using the register-values passed 
 *      through the config-structure.
 *
 *   @b Arguments
 *   @verbatim

            hIcache          Pointer to the data object for icache instance 
            icacheConfig     Pointer to setup structure which contains the
                             information to program the icache to a useful state 
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Configuration successful
 *   @li                    CSL_ESYS_BADHANDLE - Invalid handle
 *   @li                    CSL_ESYS_INVPARAMS - Invalid configuration 
 *                                               parameters    
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n     The registers of the specified icache instance will be setup 
 *          according to value passed
 *
 *   @b Modifies
 *   @n     Hardware registers of the specified icache instance
 *
 *   @b Example
 *   @verbatim         
            
            status = CSL_icacheHwSetupRaw (hIcache, &icacheConfig);
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_icacheHwSetupRaw, ".text:csl_section:icache");

CSL_Status CSL_icacheHwSetupRaw (
    CSL_IcacheHandle    hIcache,
    CSL_IcacheConfig    *icacheConfig
)
{
    CSL_Status  status;

    status = CSL_SOK;

    if (hIcache == NULL) {
        status = CSL_ESYS_BADHANDLE;
        return status;
    }

    if (icacheConfig == NULL) {
        status = CSL_ESYS_INVPARAMS;
        return status;
    }
    
    CSL_chipWriteReg (CSL_CHIP_REG_CSR, icacheConfig->CSR);
    CSL_chipWriteReg (CSL_CHIP_REG_MEMCSR, icacheConfig->MEMCSR);

    return status;

}
