/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_icacheInit.c
 *
 *   @path  $(CSLPATH)\ipmodules\icache\src
 *
 *   @desc  L1P I-cache CSL implementation 
 *  ============================================================================
 */


/* =============================================================================
 *  Revision History
 *  ===============
 *  28-Jan-2005 Ramitha Mathew File Created.
 * 
 * =============================================================================
 */

#include <csl_icache.h>

/** ============================================================================
 *   @n@b CSL_icacheInit
 *
 *   @b Description
 *   @n This is the initialization function for the icache CSL. This function 
 *      needs to be called before any other icache CSL functions are called. 
 *      This function does not modify any registers or check status.  
 *      It has been kept for future use.
 *
 *   @b Arguments
     @verbatim
            pContext    Pointer to module-context. As ICACHE doesn't have any 
                        context based information user is expected to pass NULL.

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Always returns
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_sysInit() must be called. 
 *
 *   <b> Post Condition </b>
 *   @n  None 
 *
 *   @b Modifies
 *   @n  None  
 *
 *   @b Example
 *   @verbatim
            CSL_Status      status;
            
            status = CSL_icacheInit(NULL);
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_icacheInit, ".text:csl_section:icache");

CSL_Status CSL_icacheInit (
    CSL_IcacheContext   *pContext
)
{
    /* To Remove warning */
    pContext = pContext;
    return CSL_SOK;
}
