/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/*
 *  @file  _csl_getEventHandler.c
 *
 *  @brief  INTC Functional Layer: _csl_getEventHandler (..)
 *
 *  Description
 *  - _csl_getEventHandler(..) function definition
 *  
 *  Modification
 *  - Modified on: 21/12/2004
 *  - Reason: creation
 *
 *  @author RMathew
 *
 */

#include <csl_intc.h>
#include "_csl_intc.h"
#include <soc.h>

/* 
 * Global variable which holds the vecId to indicate which isr has 
 * to be addresssed
 */
Uint32      _CSL_intcCurrentEvtNum = 0;

/** ============================================================================
 *   @n@b _csl_getEventHandler
 *
 *   @b Description
 *   @n The function obtains the isr address plugged in _CSL_intcEventHandlerRecord
 *      
 * 
 *   @b Arguments
 *   @verbatim
 *       vecId- The vector no: of event to which it is mapped 
 *
     @endverbatim
 *
 *   <b> Return Value </b> isr address 
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b  Modifies
 *   @n  None
 *
 *  @b Example:
 *   @verbatim
        _csl_getEventHandler ();
     @endverbatim

 ** =============================================================================
 */


#pragma CODE_SECTION (_csl_getEventHandler, ".text:csl_section:intc");

interrupt void _csl_getEventHandler (
    void
)
{

    register Uint32     evtId = _CSL_intcCurrentEvtNum;

    if (_CSL_intcEventHandlerRecord[evtId].handler !=
        _CSL_INTC_EVTHANDLER_UNPLUGGED) {
        /* getting the isr address from the _CSL_intcEventHandlerRecord */
        _CSL_intcEventHandlerRecord[evtId].
            handler (_CSL_intcEventHandlerRecord[evtId].arg);
    }

}
