/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcDispatcherInit.c
 *
 *  @brief  INTC Functional Layer: CSL_intcDispatcherInit(..)
 *
 *  Description
 *  - CSL_intcDispatcherInit(..) function definition
 *  
 *  Modification
 *  - Modified on: 15/12/2004
 *  - Reason: creation
 *
 *  @author RMathew
 *
 */

#include <csl_intc.h>
#include <soc.h>

#pragma DATA_SECTION (_CSL_intcEventHandlerRecord, ".bss:csl_section:intc");
/* Global pointer to CSL_intcEventHandlerRecord */
CSL_IntcEventHandlerRecord  *_CSL_intcEventHandlerRecord = NULL;

/** ============================================================================
 *  @n@b CSL_intcDispatcherInit
 *
 *  @b Description
 *  @n Hooks up and sets up the CSL interrupt dispatchers 
 *     The user should call CSL_intcDispatcherInit(..) if they
 *     wish to make use of the dispatchers built into the CSL INTC
 *     module.
 *
 * Note: This API must be called before using
 * CSL_intcPlugEventHandler(..).
 *
 *  @b Arguments
 *  @n pContext - context relevant to Dispatcher
 *
 *  <b> Return Value </b> CSL_Status
 *  @li                   CSL_SOK on success
 *  @li                   CSL_ESYS_ALREADY_INITIALIZED 
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b  Modifies
 *   @n  None
 *
 *
 * @b Example:
 * @verbatim
      if ((CSL_intcInit( ) != CSL_SOK) || 
           (CSL_intcInit() != CSL_ESYS_ALREADY_INITIALIZED)
         )
         {
         // module initialization failed! //
         }
      if ((CSL_intcDispatcherInit( ) != CSL_SOK) && 
           (CSL_intcDispatcherInit( ) != CSL_ESYS_ALREADY_INITIALIZED)
         )
         {
         // CSL dispatcher setting up failed! //
         }
   @endverbatim
 *
 * =============================================================================
 */ 

#pragma CODE_SECTION (CSL_intcDispatcherInit, ".text:csl_section:intc")
CSL_Status CSL_intcDispatcherInit (
    CSL_IntcDispatcherContext   *pContext
)
{
    CSL_Status      status;

    if (_CSL_intcEventHandlerRecord == NULL) {
        _CSL_intcEventHandlerRecord = pContext->eventHandlerRecord;
        status = CSL_SOK;
    }
    else {
        status = CSL_ESYS_ALREADY_INITIALIZED;
   } 

    return status;
}
