/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcEventRestore.c
 *
 *  @brief  INTC Functional Layer: CSL_intcEventRestore(..)
 *
 *  Description
 *  - CSL_intcEventRestore(..) function definition
 *  
 *  Modification
 *  - Modified on: 14/12/2004
 *  - Reason: creation 
 *
 *  @author RMathew
 *
 */

#include <csl_intc.h>
#include "_csl_intc.h"
#include <soc.h>


extern CSL_IntcEventEnableState _CSL_intcEventEnable (
    _CSL_IntcVecId,
    Uint32
);
extern CSL_IntcEventEnableState _CSL_intcEventDisable (
    _CSL_IntcVecId,
    Uint32
);

/** ============================================================================
 *  @n@b CSL_intcEventRestore
 *
 *  @b Description
 *  @n The API restores the specified event to a previous enable-state
 *     as recorded by the event-enable state passed as an argument.
 *     Note: The function directly works on the event and hence it is
 *     not necessary to "open" the event to invoke the API.
 *
 *  @b Arguments
 *  @verbatim
        eventId     Event-ID of interest        
        prevState   Object that contains information about previous state
    @endverbatim
 *
 *  <b> Return Value </b> CSL_Status
 *  @li                   CSL_SOK on success
 *  @li                   CSL_INTC_EVENTID_INVALID 
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n The IER register.
 *
 *
 * @b Example:
 * @verbatim
        CSL_intcEventRestore(CSL_INTC_EVENTID_SPI, oldState);
   @endverbatim
 *
 * =============================================================================
 */
 
#pragma CODE_SECTION (CSL_intcEventRestore, ".text:csl_section:intc");

CSL_Status CSL_intcEventRestore (
    CSL_IntcEventId             eventId,
    CSL_IntcEventEnableState    prevState
)
{
    CSL_Status      status = CSL_SOK;
    Uint32          vecId;

    if (eventId >= CSL_INTC_EVENTID_RESET && eventId
        <= CSL_INTC_EVENTID_DMAXEVTOUT7) {
        /* getting the interrupt vector to which the event is mapped */
        vecId = 31 - _lmbd (1, _CSL_IntcEventTable[eventId]);
        if (prevState == CSL_INTC_EVENT_ENABLE) {
            _CSL_intcEventEnable (_CSL_IntcEventTable[eventId], vecId);
        }
        else {
            _CSL_intcEventDisable (~(_CSL_IntcEventTable[eventId]), vecId);
        }
    }
    else {
        status = CSL_INTC_EVENTID_INVALID;
    }

    return status;
}
