/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcGlobalEnable.c
 *
 *  @brief  INTC Functional Layer: CSL_intcGlobalEnable (..)
 *
 *  Description
 *  - CSL_intcGlobalEnable (..) function definition
 *  
 *  Modification
 *  - Modified on: 14/12/2004
 *  - Reason: creation
 *
 *  @author RMathew
 *
 */

#include <csl_intc.h>

extern CSL_IntcGlobalEnableState _CSL_intcGlobalEnable (
    void
);

/** ============================================================================
 *  @n@b CSL_intcGlobalEnable
 *
 *  @b Description
 *  @n The API enables the global interrupt by manipulating the processor's
 *     global interrupt enable/disable flag. If the user wishes to restore
 *     the enable-state at a later point, they may store the current state
 *     using the parameter, which could be used with CSL_intcGlobalRestore(..).
 *
 *  @b Arguments
 *  @verbatim
        prevState   (Optional) Pointer to object that would store current
                    stateObject that contains information about previous state
    @endverbatim
 *
 *  <b> Return Value </b> CSL_Status
 *  @li                   CSL_SOK on success
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n The CSR register.
 *
 *
 *  @b Example:
 *  @verbatim
    CSL_intcGlobalEnable(NULL);
    @endverbatim
 *
 * =============================================================================
 */
 
 #pragma CODE_SECTION (CSL_intcGlobalEnable, ".text:csl_section:intc");
 
CSL_Status CSL_intcGlobalEnable (
    CSL_IntcGlobalEnableState   *prevState
)
{
    CSL_IntcGlobalEnableState gie;

    /* enables the global interrupt flag bit */
    gie = (CSL_IntcGlobalEnableState) _CSL_intcGlobalEnable ();
    if (prevState) {
        *prevState = gie;
    }
    return CSL_SOK;
}
