/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcGlobalRestore.c
 *
 *  @brief  INTC Functional Layer: CSL_intcGlobalRestore (..)
 *
 *  Description
 *  - CSL_intcGlobalRestore (..) function definition
 *  
 *  Modification
 *  - Modified on: 14/12/2004
 *  - Reason: creation 
 *
 *  @author RMathew
 *
 */

#include <csl_intc.h>


extern CSL_IntcGlobalEnableState _CSL_intcGlobalEnable (
    void
);
extern CSL_IntcGlobalEnableState _CSL_intcGlobalDisable (
    void
);

/** ============================================================================
 *  @n@b CSL_intcGlobalRestore
 *
 *  @b Description
 *  @n The API restores the global interrupt enable/disable state to a previous
 *    state as recorded by the global-event-enable state passed as an argument.
 *
 *  @b Arguments
 *  @verbatim
        prevState   Object containing information about previous state
    @endverbatim
 *
 *  <b> Return Value </b> CSL_Status
 *  @li                   CSL_SOK on success
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n The CSR register.
 *
 *
 *  @b Example:
 *  @verbatim
     CSL_IntcGlobalEnableState   gieState;
  
     CSL_intcGlobalDisable(&gieState);
     // critical-section code //
     CSL_intcGlobalRestore(gieState);
    @endverbatim
 *
 * =============================================================================
 */
 
 #pragma CODE_SECTION (CSL_intcGlobalRestore , ".text:csl_section:intc");

CSL_Status CSL_intcGlobalRestore (
    CSL_IntcGlobalEnableState   prevState
)
{
    if (prevState == CSL_INTC_GLOBAL_ENABLE)
        _CSL_intcGlobalEnable ();
    else
        _CSL_intcGlobalDisable ();

    return CSL_SOK;

}
