/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**
 *  @file  csl_intcHwSetup.c
 *
 *  @brief  INTC Functional Layer: CSL_intcHwSetup(..)
 *
 *  Description
 *  - CSL_intcHwSetup(..) function definition
 *  
 *  Modification
 *  - Modified on: 15/12/2004
 *  - Reason: creation
 *
 *  @author RMathew
 *
 */

#include <csl_intc.h>
#include <soc.h>

/** ============================================================================
 *   @n@b CSL_intcHwSetup
 *
 *   @b Description
 *   @n CSL_intcHwSetup(..) API is used to configure the interrupt controller
 *      for the event identified by the handle. The user must instantiate
 *      and initialize a setup-structure with appropriate configuration
 *      parameters before passing it to the function.
 *   
 *   @b Arguments
 *   @verbatim
       hIntc        Handle to the INTC instance          
       hwSetup      Pointer to harware setup structure
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK -  always return
 *
 *   <b> Pre Condition </b>
 *   @n  Module must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n None
 *
 *   @b IMPORTANT NOTE
 *      ==============
 *   @n In C672x\DA7xx CSL_intcHwSetup() is a function which does nothing as 
 *      no h/w configuration is to be done
 *
 *   @b Example:
 *   @verbatim
        Here just pass the CSL_IntcHwSetup* as NULL        
        CSL_intcHwSetup(hIntc, &setup);  
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_intcHwSetup, ".text:csl_section:intc");

CSL_Status CSL_intcHwSetup (
    CSL_IntcHandle      hIntc,
    CSL_IntcHwSetup     *setup
)
{
    hIntc = hIntc;
    setup = setup;
    return CSL_SOK;
}
