/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/**  @file  csl_intcSetVectorPtr.c
 *
 *  @brief  INTC Functional Layer: CSL_intcSetVectorPtr(..)
 *
 *  Description
 *  - CSL_intcSetVectorPtr(..) function definition
 *  
 *  Modification
 *  - Modified on:  10/03/2005
 *  - Reason: creation 
 *
 *  @author Ramitha Mathew
 *
 */

#include <csl_intc.h>


extern Uint32 _CSL_intcISTP (
    Uint32
);


/** ============================================================================
 *  @n@b CSL_intcSetVectorPtr
 *
 *  @b Description
 *  @n The API changes the base address of the Interrupt Vector table to the 
 *     value passed.
 *
 *  @b Arguments
 *  @verbatim
        vecPtr   New base address of the Interrupt Vector Table. Care should be 
                 taken that first ten lower bits are all zeroes
    @endverbatim
 *
 *  <b> Return Value </b> 
 *  @li                   Previously loaded ISTP value
 *
 *  @b Example:
 *  @verbatim
    
    #define VEC_ADDR        0x100c0000
    Uint32 prevValue;
    
    
    prevValue = CSL_intcSetVectorPtr (VEC_ADDR);
    
    @endverbatim
 *
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_intcSetVectorPtr, ".text:csl_section:intc");

Uint32 CSL_intcSetVectorPtr (
    Uint32 vecPtr
)
{
    Uint32                      prev;
    CSL_IntcGlobalEnableState   gie;

    CSL_intcGlobalDisable (&gie);

    /* calling the private function to load the ISTP register */
    prev = _CSL_intcISTP (vecPtr);

    CSL_intcGlobalRestore (gie);

    return prev;
}
