/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  csl_rtiClose.c
 *
 *   @path  $(CSLPATH)\ipmodules\rti\src
 *
 *   @desc  Real Time Interrupt CSL implementation for module close
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  1-Dec-2004 Sd File Created.
 *
 * =============================================================================
 */
 
#include <csl_rti.h>

/** ============================================================================
 *   @n@b csl_rtiClose.c
 *
 *   @b Description
 *   @n This function marks that CSL for the real time interrupt instance is 
 *      closed. CSL for the real time interrupt instance need to be reopened 
 *      before using any real time interrupt CSL API.
 *      
 *   @b Arguments
 *   @verbatim
            hRti         Handle to the real time interrupt instance 
     @endverbatim
 *
 *   <b> Return Value </b> CSL_Status
 *   @li                   CSL_SOK - Real Time Interrupt is closed successfully
 *   @li                   CSL_ESYS_BADHANDLE - The handle passed is invalid
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  1. The real time interrupt CSL APIs can not be called until the real 
 *          time interrupt CSL is reopened again using CSL_rtiOpen() 
 *
 *   @b Modifies
 *   @n  None
 *            
 *   @b Example
 *   @verbatim
            CSL_RtiHandle   hRti;
            
            ...
            
            CSL_rtiClose (hRti);
            
            ...
     @endverbatim
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_rtiClose, ".text:csl_section:rti");

CSL_Status CSL_rtiClose (
    CSL_RtiHandle   hRti
)
{
    CSL_Status      status;

    if (hRti != NULL) {
        hRti->regs = (CSL_RtiRegsOvly) NULL;
        hRti->perNum = (CSL_InstNum) - 1;
        status = CSL_SOK;
    }
    else {
        status = CSL_ESYS_BADHANDLE;
    }

    return status;
}
