/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_rtiInit.c
 *
 *   @path  $(CSLPATH)\ipmodules\rti\src
 *
 *   @desc  Real Time Interrupt CSL implementation for module initialization
 *
 */
 
/* =============================================================================
 *  Revision History
 *  ===============
 *  1-Dec-2004 Sd File Created.
 *
 * =============================================================================
 */
 
#include <csl_rti.h>

/** ============================================================================
 *   @n@b CSL_rtiInit
 *
 *   @b Description
 *   @n This is the initialization function for the real time interrupt CSL. The
 *      function must be called before calling any other API from this CSL.
 *      This function is idem-potent. Currently, the function just return status
 *      CSL_SOK, without doing anything.
 *
 *   @b Arguments
 *   @verbatim
        pContext    Pointer to module-context. As real time interrupt doesn't 
                    have any context based information user is expected to 
                    pass NULL.
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Always returns
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_sysInit() must be called. 
 *
 *   <b> Post Condition </b>
 *   @n  The CSL for real time interrupt is initialized 
 *
 *   @b Modifies
 *   @n  None  
 *
 *   @b Example
 *   @verbatim
            CSL_rtiInit(NULL);
     @endverbatim
 * =============================================================================
 */ 
#pragma CODE_SECTION (CSL_rtiInit, ".text:csl_section:rti");
CSL_Status CSL_rtiInit (
    CSL_RtiContext  *pContext
)
{
    pContext = pContext;
    return CSL_SOK;
}
