/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_spiClose.c
 *
 *  @path $(CSLPATH)\spi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_spiClose()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  24-Jan-2005 GaneshK File Created.                 
 * =============================================================================
 */

#include <csl_spi.h>

/** ===========================================================================
 *   @func CSL_spiClose
 *
 *   @b Description
 *   @n This function closes the specified instance of SPI.
 *
 *   @arg  hSpi
           Handle to the Spi instance
 *
 *   @ret CSL_Status
 *         CSL_SOK            - Close successful
 *         CSL_ESYS_BADHANDLE - Invalid handle
 *
 *   <b> Pre Condition </b>
 *   @n  Both @a CSL_spiInit() and @a CSL_spiOpen() must be called successfully
 *       in that order before @a CSL_spiClose() can be called.
 *
 *   <b> Post Condition </b>
 *   @n  None.
 *
 *   @b Example
 *   @verbatim
        CSL_SpiHandle       hSpi;
        CSL_Status          status;
        
        ...
        status = CSL_spiClose (hSpi);
        ...
     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CSL_spiClose, ".text:csl_section:spi");

CSL_Status CSL_spiClose (
    /* 
     * Pointer to the object that holds reference to the
     * instance of SPI requested after the call
     */
    CSL_SpiHandle hSpi
)
{
    CSL_Status               status;

    if (hSpi != NULL) {
        hSpi->regs = (CSL_SpiRegsOvly) NULL;
        hSpi->perNum = (CSL_InstNum) - 1;
        status = CSL_SOK;
    }
    else {
        status = CSL_ESYS_BADHANDLE;
    }

    return status;
}
