/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** @file  csl_spiInit.c
 *
 *  @path $(CSLPATH)\spi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_spiInit()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  24-Jan-2004 GaneshK author  File Created.
 * =============================================================================
 */

#include <csl_spi.h>

/** ============================================================================
 *   @n@b CSL_spiInit
 *
 *   @b Description
 *   @n This is the initialization function for the SPI. This function is 
 *   idempotent in that calling it many times is same as calling it once. This 
 *   function does not modify any registers or check status. It returns status 
 *   CSL_SOK. It has been kept for future use.
 *
 *   @b Arguments
     @verbatim
            pContext   Context information for the instance. Should be NULL
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK - Always returns
 *
 *   <b> Pre Condition </b>
 *   @n  CSL_sysInit() must be called. 
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim
		
	CSL_Status 	Status;
    ...		
	Status = CSL_spiInit();

   @endverbatim
 *  ===========================================================================
 */
#pragma CODE_SECTION (CSL_spiInit, ".text:csl_section:spi");
CSL_Status
CSL_spiInit (
    CSL_SpiContext * pContext
)
{
    pContext = pContext;
    return CSL_SOK;
}
