/*  ===========================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ==========================================================================
 */

/** @file  csl_uhpiClose.c
 *
 *  @path $(CSLPATH)\uhpi\src
 *
 *  @brief File for functional layer of CSL API @a CSL_uhpiClose()
 *
 */

/* ============================================================================
 *  Revision History
 *  ===============
 *  
 *  28-Jan-2005 asr asr File Created.                    
 * ============================================================================
 */

#include <csl_uhpi.h>

/** ===========================================================================
 *   @n@b CSL_uhpiClose
 *
 *   @b Description
 *   @n This function closes the specified instance of UHPI.
 *
 *   @b Arguments
 *   @verbatim
            hUhpi            Handle to the UHPI

     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             - Close successful
 *   @li                    CSL_ESYS_BADHANDLE  - Invalid handle
 *
 *   @b Example
 *   @verbatim
            CSL_UhpiHandle      hUhpi;
            CSL_Status          status;

            ...
            
            status = CSL_uhpiClose (hUhpi);
     @endverbatim
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_uhpiClose, ".text:csl_section:uhpi");

CSL_Status CSL_uhpiClose (
    CSL_UhpiHandle	hUhpi
)
{
    CSL_Status	status;

    if (hUhpi != NULL) {
        hUhpi->regs = (CSL_UhpiRegsOvly) NULL;
        hUhpi->uhpiNum = (CSL_InstNum) -1;
        status = CSL_SOK;
    }
    else {
        status = CSL_ESYS_BADHANDLE;
    }

    return status;
}
